*********************************************

*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***********TTL: Arden Finn and Alia Jane************

*********************************************
/*
set type double 
set more off 
clear all 

use "${datapath}indvweight.dta", clear

	ren id00 hhid
	merge m:1 hhid using "${datapath}PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta"
	drop _m
	ren hhid id00
	lab var id00 "Household ID"
	lab var d1 "Personal ID"
	lab var weightt "Individual weights"
		//Notes: these weights vary by individual, and have been calibrated to match Palestine age and sex population totals
	lab var rw "Individual reweight index"

	bys id00: egen hhweight = mean(weightt)
	lab var hhweight "HH weights derived from individual weights"

	qui sum weightt
	disp r(sum)   //4.9465153 m individuals - these are the weights that actually match the population.

	qui sum hhweight
	disp r(sum)  //4.9465153 m individuals - correct

	count //20,185

save "${temppath}indvweights.dta", replace

	keep if d1 == 1

	qui sum hhweight [w=hhsize]
	disp r(sum)  // 4946515.3

	cap g popw  = hhweight*hhsize
	lab var popw "Population / per capita weights"
	 
	qui sum popw
	disp r(sum)
	
	ren id00 hhid

save "${temppath}hhweight.dta", replace
 
*/

use "${temppath}hhweight_v2.dta", clear
	lab var id01 "District / Governerate"
	lab var id02 "Locality"
	lab var id03 "EA"

	*tab id01 
	*tab id02 
	*tab id03

	recode id01 (41=40), g(district)

	lab define district_lbl 1"Jenin" 5"Tubas & the Northern Valleys" 10	"Tulkarm" 15"Nablus" 20	"Qalqiliya" 25"Salfeet" 30"Ramallah & Al-Bireh" 35"Jericho" 40"Jerusalem" 45"Bethlehem" 50"Hebron" 55"GS-North" 60"Gaza City" 65"Deir AlBalah" 70"Khan Younis" 75"Rafah" 
	lab val district district_lbl

	*tab district
	
	keep if d1 == 1 
	drop d1

	qui sum hhweight [w=hhsize]
	disp r(sum)

	qui sum popw 
	disp r(sum)

	qui sum gall [w=popw] // if region != 3
	global cons_svy = r(sum)
	disp $cons_svy/1e9   //51.33

	lab var hhid "Household ID"


	replace region=3 if inlist(district,40,41)
	lab define region_lbl 1 "West Bank" 2 "Gaza" 3 "East Jerusalem"
	lab val region region_lbl

	quantiles gall [w=hhweight*hhsize], nq(10) gencatvar(dec)
	quantiles gall [w=hhweight*hhsize] if inlist(region,1,2), nq(10) gencatvar(dec_wb_gz)
	quantiles gall [w=hhweight*hhsize] if inlist(region,1,3), nq(10) gencatvar(dec_wb_ej)
	quantiles gall [w=hhweight*hhsize] if region == 1, nq(10) gencatvar(dec_wb)
	quantiles gall [w=hhweight*hhsize] if region == 2, nq(10) gencatvar(dec_gz)
	quantiles gall [w=hhweight*hhsize] if region == 3, nq(10) gencatvar(dec_ej)

	quantiles gall [w=hhweight*hhsize], nq(5) gencatvar(qui)
	quantiles gall [w=hhweight*hhsize] if inlist(region,1,2), nq(5) gencatvar(qui_wb_gz)
	quantiles gall [w=hhweight*hhsize] if inlist(region,1,3), nq(5) gencatvar(qui_wb_ej)
	quantiles gall [w=hhweight*hhsize] if region == 1, nq(5) gencatvar(qui_wb)
	quantiles gall [w=hhweight*hhsize] if region == 2, nq(5) gencatvar(qui_gz)
	quantiles gall [w=hhweight*hhsize] if region == 3, nq(5) gencatvar(qui_ej)

	ren hhid id00

compress
save "${temppath}hhweight_quantiles.dta", replace
