****************************************************
*****PALESTINE: Fiscal Incidence Analysis***********
*****World Bank, Poverty and Equity GP**************
***********TTL: Arden Finn and Alia Jane************
*********Consultant: Haydeeliz Carrasco*************
*********Edited by Maya Goldman  (18 Jan 2023)******
****************************************************

	set more off, permanently 
	clear all 
	set type double

	set varabbrev on 

	**SET UP Folders**
	
	global main "C:/Users/wb614536/OneDrive - WBG/Documents/Reproducibility/RR_PSE_2024_20-v04/Reproducibility package/Stata/"

	cd "${main}"
	
    sysdir set PLUS "ados"

	global dofiles 		"do-files/"

* Raw data folders 
	global datapath 	"rawdata\"
	global datalfs 		"${datapath}\LFS_2017\Q4-2017\"
	*global harm 		"data\source\pecs_2016\Harmonized\PSE_2016_PECS_v01_M_v04_A_MNAPOV\"
	global theado 		"ados\" 

* Processed data folders 
	global outputpath 	"output\"
	global temp  		"$outputpath\temp\"
	global proc 		"$temp\"
	global temppath  	"$temp\"
	
	global io 			"$main\rawdata\io\"   //storing these in a separate folder so that they don't get deleted 

* Output summary
	global date 		"\2023-09-28"
	global results 		"$temp\"
	global mwbe_pdi 	"mwb\E-section\pdi\"
	global mwbe_pgt 	"mwb\E-section\pgt\"
	global graph		"$outputpath\graphs\${date}\"

*For Currency exchange
	global JODtoNIS 5.4465074246 // as of 20170101, source: xe
	global USDtoNIS 3.8517700000 // as of 20170101, source: xe
	global hhweight "whhs"
	global cons_admn = 55.087*1e9

*===============================================================================
		*Run necessary ado files
*===============================================================================
	
*	local files : dir "$theado" files "*.ado"
*	foreach f of local files{
*		cap install "$theado\\`f'"
*		dis in yellow "`f'"
*		qui: run "$theado\\`f'"
*	}

*===============================================================================
		*Do files 
*===============================================================================

	* Cleaning any temporary data

	local tmp_1: dir "${temp}" files "*.dta"
	local tmp_2: dir "${outputpath}" files "*.dta"

	
	foreach tmpf in `tmp_1' {
		erase "${temp}\`tmpf'"
	}
	foreach tmpf in `tmp_2' {
		erase "${outputpath}\`tmpf'"
	}

*===============================================================================
		*Do files 
*===============================================================================

	include "${dofiles}00_PSE hh weights.do"
	include "${dofiles}00_PSE hhweight_quantiles.do"
	include "${dofiles}01_PSE_education transfers.do"
	include "${dofiles}02_PSE_Property tax_alt.do"
	include "${dofiles}03_PSE_IO VAT.do"
	include "${dofiles}04_PSE_VAT_all.do"
	include "${dofiles}05_PSE_custom duties.do"
	include "${dofiles}07_PSE health benefits.do"
	include "${dofiles}08_PSE fuel subsidies.do"
	include "${dofiles}09. PSE_elec_sub_dir_v3.do"
	include "${dofiles}10_PSE_SocialProtection.do"
	include "${dofiles}11.1_PSE_pit_prep.do"
	include "${dofiles}11.3_PSE_pit_model.do"
	include "${dofiles}11.4_PSE_pit_conpens.do"
	include "${dofiles}12_PSE excises.do"
	include "${dofiles}99_PSE_ CEQ income concepts.do"
	*include "${dofiles}999_PSE FIA Results.do"			//Produces the graphs that were used for the PowerPoint presentation - no longer needed for report 
	include "${dofiles}100_PSE_harm.do"					//Produce the harmonised dataset
	include "${dofiles}102. PSE_indicators.do"			//Produce the datasets with indicators ready to produce graphs 
	include "${dofiles}103. PSE_graphs_report.do"   	//Produce the graphs for the PSE report 


**********************************************************************************
* End 
**********************************************************************************
