****************************************************
*****PALESTINE: Fiscal Incidence Analysis***********
*************World Bank, Poverty and Equity GP*********
***********TTL: Arden Finn and Alia Jane********
**************Consultant: Haydeeliz Carrasco***********
*******************************************************
*Date modified: July 5th, 2023

clear
set more off
set type double

*===============================================================================
		*Run necessary ado files
*===============================================================================
	
	local files : dir "$theado" files "*.ado"
	foreach f of local files{
		dis in yellow "`f'"
		qui: run "$theado\\`f'"
	}
	
	
***SET SIMULATION PARAMETERS***//Annual transfers per benef (executed)
global basic_transf=2352 
global second_transf=5061
global basic_stud_target= 585821 //target admin number of basic educ beneficiaries to avoid overestimation [NEW]

***CREATE MASTER DATASET****
use "${datapath}\PSE\PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
drop popw

merge 1:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 
drop _m

ren hhid id00
merge 1:m id00 using "${datapath}\PSE\roster.dta"
drop if _m!=3 
drop _m

ren id00 hhid

save "${temppath}PSE education master.dta", replace

use "${temppath}PSE education master.dta", clear //OPEN MASTER DATASET

*****STEP 1: CREATE RELEVANT VARIABLES FOR THE MODEL*****

*Current level of education
ta d18
gen current_edu_level=0 
	*replace current_edu_level=d18  if d18>=1 & d18<=11 //only generate grade for basic and secondary students
	replace current_edu_level=d18+1 if d16==1 //add 1 year if they are currently enrolled since d18 was "highest grade completed"
	
*Dummies for basic and secondary school
gen basic_level=0
	replace basic_level=1 if d16==1 & current_edu>=1 & current_edu<=10

gen second_level=0
	replace second_level=1 if d16==1 & current_edu==11 | current_edu==12 & d16==1
	
*Dummy for government school
gen public_stud=0
	replace public_stud=1 if d22==1
ta public_stud if basic_level==1| second_level==1  [fw=int(hhweight)] //986479 students in public schools, basic and second (vs. 800,484 in admin)

*Dummies for level and govt school
gen basic_pub=0
	replace basic_pub=1 if basic_level==1 & public_stud==1
	replace basic_pub=0 if  id01==40|id01==41 //Exclude East Jerusalem
	
gen second_pub=0
	replace second_pub=1 if second_level==1 & public_stud==1
	replace second_pub=0 if  id01==40|id01==41 //Exclude East Jerusalem

*Random selection of basic-education beneficiaries to reach admin number
wsample basic_pub if basic_pub==1 [aw=weight], value($basic_stud_target) newvar(sim_basic_pub) seed(0001021) //Q: Why ado is not running now?
	//basic_pub is eligible population,  $basic_stud_target is the target 

replace sim_basic_pub=0 if sim_basic_pu==.
ta sim_basic_pub [fw=int(weight)], m //HC: Ok- We get a number close to the admin target (We get 584,191 and target was 585821)

**Option 1: Deciles of real per capita consumption differentiated by region
quantiles gall [w=popw] if region ==1, nq(10) gencatvar(dec1)
quantiles gall [w=popw] if region ==2, nq(10) gencatvar(dec2)
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
quantiles gall [w=popw], nq(10) gencatvar(dec_nac)


*Total nominal consumption
gen gall_n_hh=gall_n*hhsize


****STEP 2: ALLOCATION OF PUBLIC TRANSFERS FOR ELIGIBLE BENEFICIARIES****
gen basic_transf=0
	replace basic_transf=$basic_transf if sim_basic_pub==1

gen second_transf=0	
	replace second_transf=$second_transf if second_pub==1
	
gen TOT_edu_transf=basic_transf+second_transf	

gen all=1

***STEP 3: COLLAPSE AND SAVE AT THE HH LEVEL ****
collapse (first) gall* region urban popw hhweight pline* decile hhsize dec_nac (sum) TOT_edu_transf basic_transf second_transf sim_basic_pub second_pub all, by (hhid)

save "${temppath}PSE_Edu transfers_HH.dta", replace

***STEP 4: EXPLORE PRELIMINARY RESULTS ****  
*Incidence of transfers
use "${temppath}PSE_Edu transfers_HH.dta", clear
collapse (sum) TOT_edu_transf basic_transf second_transf gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Education transfers.xls", firstrow(var) sheet(Sheet1, modify) 

use "${temppath}PSE_Edu transfers_HH.dta", clear
collapse (sum) TOT_edu_transf basic_transf second_transf gall_n_hh [fw=int(hhweight)], by(region dec_nac)
export excel using "$results\PSE_Education transfers.xls", firstrow(var) sheet(Sheet3, modify) 

*Distribution of public school students by region and level
use "${temppath}PSE_Edu transfers_HH.dta", clear
collapse (sum) sim_basic_pub second_pub [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Education transfers.xls", firstrow(var) sheet(Sheet2, modify) 

