*********************************************
*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***********TTL: Arden Finn and Alia Jane************
*********Consultant: Haydeeliz Carrasco*************
****************************************************
*Date:  April 27th 2022
/* Maya: note that I made only one small edit to this file - to remove the line where we generate popw, 
	because in the new version of the model popw is already included in the datasets that we merge at the beginning */

/*DOFILE: CALCULATION OF HEALTH IN-KIND BENEFITS*/

/* Notes from meeting with Haydeeliz

. PECS doesn't include those who have access to health care, so we divide both hospital and primary services by number of insured. 
. Also: lots of people go to UNRWA facilities, which we don't measure, so we may be overestimating the role of the government. 
. The health team didn't give us much feebback about what the barriers to access might be so we left it as is. 

*/

**SIMULATION PARAMETERS**
global pub_hospitals_exp= 1532175645  //2017 Annual Govt Expenditure in Hospitals
global pub_ambulatory_exp= 500001425 //2017 Annual Govt Expenditure in Ambulatory Services

****PREPARE MASTER DATASET****

use "${datapath}\PSE\PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
drop popw

merge 1:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 
drop _m

ren hhid id00
merge 1:m id00 using "${datapath}\PSE\roster.dta"
drop if _m!=3 
drop _m

ren id00 hhid

save "${temppath}PSE health master.dta", replace

***STEP 1: PREPARE RELEVANT VARIABLES ****

*Does the person have health insurance?
ta d9 [fw=int(hhweight)] //3937414=yes

*Government health insurance?
ta d10_1 [fw=int(hhweight)], m //2.9 mm
disp  2900352/3937414  //73.6% of those that have health insurance is govt insurance

*Define public health beneficiaries
gen public_health_benef=0
	replace public_health_benef=1 if d10_1 ==1 
	*replace public_health_benef=1 if region==2 //All Gaza residents are covered by Govt insurance according to Health Admin docs
	replace public_health_benef=0 if  id01==40|id01==41 //Exclude East Jerusalem

ta public_health_benef [fw=int(hhweight)] //66.4 % of the population
ta public_health_benef region [fw=int(hhweight)]

**Option 1: Deciles of real per capita consumption differentiated by region

quantiles gall [w=popw] if region ==1, nq(10) gencatvar(dec1)
quantiles gall [w=popw] if region ==2, nq(10) gencatvar(dec2)
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
quantiles gall [w=popw], nq(10) gencatvar(dec_nac)

*Total nominal consumption
gen gall_n_hh=gall_n*hhsize

	
***STEP 2: CALCULATE HEALTH TRANSFERS PER BENEFICIARY****
/*NOTE: The PECS 2016/17 does not have information about the health usage of beneficiaries, only about health insurance.
Hence, we will use the insurance based approach (impute transfer to individuals insured by the Govt) instead of the average cost approach (impute transfer to individuals that access public health facilities) */

gen hospitals_health_ben=0
	replace hospitals_health_ben=$pub_hospitals_exp/3307996 if public_health_benef==1 
gen ambulatory_health_ben=0
	replace ambulatory_health_ben=$pub_ambulatory_exp/3307996  if public_health_benef==1 
	
gen TOT_health_transf=hospitals_health_ben+ambulatory_health_ben

gen all=1

***STEP 3: COLLAPSE AND SAVE AT THE HH LEVEL ****
collapse (first) gall* region id01 urban popw hhweight pline* decile hhsize dec_nac (sum) TOT_health_transf hospitals_health_ben ambulatory_health_ben public_health_benef all, by (hhid)

save "${temppath}PSE_Health transfers_HH.dta", replace

***STEP 4: CALCULATE PRELIMINARY RESULTS ***
 
*Incidence of transfers
use "${temppath}PSE_Health transfers_HH.dta", clear
collapse (sum) TOT_health_transf hospitals_health_ben ambulatory_health_ben gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Health transfers.xls", firstrow(var) sheet(Sheet1, modify) 

*Distribution of public school students by region and level
use "${temppath}PSE_Health transfers_HH.dta", clear
collapse (sum) public_health_benef all [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Health transfers.xls", firstrow(var) sheet(Sheet2, modify) 
