****************************************************
*****PALESTINE: Fiscal Incidence Analysis***********
*************World Bank, Poverty and Equity GP*********
***********TTL: Arden Finn********
**************Prepared by: Beenish Amjad***********
***********Electricity Subsidy****************************
*******************************************************
*Date: March 24, 2023

*DOFILE: Electricity subsidy- consumption data 2017-18, slab structure 2017-18*/

*-------------------------------------------------------------------------------
* PART 1- Budget Share 
*		1.0 Data cleaning
*-------------------------------------------------------------------------------

*===============================================================================
	* SECTION A: Prepare Electricity Subsidy dataset
*===============================================================================

use "${datapath}/PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta" , clear  //3739
ren hhid id00
merge 1:m id00 using "${datapath}PSE/PSE_Master Consumption.dta"  //350 th 
drop if _m!=3
drop _m
 

*Merge with dataset that has hh weights
merge m:1 id00 using "${temppath}hhweight_quantiles.dta"
ren id00 hhid
codebook hhid
drop if _m!=3 
drop _m

save "${temppath}PSE_Electr_master.dta", replace

*===============================================================================
    * SECTION B: Create variables and parameters of beneficiaries
*===============================================================================
use "${temppath}PSE_Electr_master.dta", clear
ren mvalue expend

gen elec		=(item==2903)				//electricity expenditures in hh survey
gen gas			=(item==2905)				//gas expenditures in hh survey
gen kero		=(item==2907)				//kerosene expenditures in hh survey

gen exp_ele=expend if elec==1				//in survey the recall period for electricity expenditure is one month
gen exp_ele_ann=exp_ele*12					//annualize it
summ exp_ele_ann
summ exp_ele								//average monthly consumption NIS-186

save "${temppath}baselineenergy_PSE.dta", replace


*-------------------------------------------------------------------------------
* PART 2: Compute subsidies
*-------------------------------------------------------------------------------
*Calculate quantities
	*i) Limitation: there is no break-down of the tariff structure component therefore we don't have information if any applicable adjustments and taxes are included or not
	*ii) Assumption: tariff structure is with all tariff adjustments (FPA or QTA or any other applicable) and WITHOUT any tax.
	*iii) As a result of above assumption, taxes are added to the price 
	*iv) Assume volumetric structure

use "${temppath}baselineenergy_PSE.dta", replace

#delimit ;
matrix input price_el =
(
0.458 \
0.4938 \
0.5695 \
0.6089 \
0.6731 
);
#delimit cr

*max1=price of that slab 0.458*160*0.16 (price of slab * max consumption of slab) * 16%(VAT)
sca def max1=85
sca def max2=143.20
sca def max3=264.25
sca def max4=423.79
sca def max5=468.48

*generate quantities
gen qt_ele=0
replace qt_ele= exp_ele/(price_el[1,1]*1.16) if exp_ele<=max1 
replace qt_ele= exp_ele/(price_el[2,1]*1.16) if exp_ele>max1 & exp_ele<=max2
replace qt_ele= exp_ele/(price_el[3,1]*1.16) if exp_ele>max2 & exp_ele<=max3
replace qt_ele= exp_ele/(price_el[4,1]*1.16) if exp_ele>max3 & exp_ele<=max4
replace qt_ele= exp_ele/(price_el[5,1]*1.16) if exp_ele>max5 & exp_ele!=.
gen qt_ele_ann=qt_ele*12


*Generate consumption slabs
gen slab=0 if qt_ele<=1 
replace slab=1 if qt_ele>1&qt_ele<=160
replace slab=2 if qt_ele>160&qt_ele<=250
replace slab=3 if qt_ele>250&qt_ele<=400
replace slab=4 if qt_ele>400&qt_ele<=600
replace slab=5 if qt_ele>600&qt_ele!=.
rename slab slab_ele

label define ssl  0 "[0]" 1 "[1-160]" 2"[161-250]" 3"[251-400]" 4"[401-600]" 5"600+" 
label values slab_ele ssl

*define access electricity
gen access_ele=exp_ele>0

save "${temppath}baselineenergy_PSE.dta", replace

use "${temppath}baselineenergy_PSE.dta", replace

*-------------------------------------------------------------------------------
/* To compute the subsidy there are two options
i) take per unit subsidy as defined by the Government which is "subsidy amount provided in the law (Article 4) 0.0156 NIS per unit Source: Article 5, Ministerial decision N 03/137/17 of the year 2017	;
ii) take the difference between the average cost of electricity per kWh and tariff paid by the consumer 

TTL has suggested to use option ii above;
*1) check the difference between the average cost of electricity per kWh and the average tariff paid by consumers, w/o fixed costs.
	*we don't have information about average cost. We have information about Cost of purchase for Palestinian DISCOS for 2016-17 per kWh. It is NIS 0.53– 0.56 (US$0.14–0.15) per kWh
	*we have assumed that distribution margin is 20%
		To compute the subsidy following steps are taken;
		*i) assumed all the domestic consumers are single phase
		*ii)subsidy is defined as difference between cost of electricity purchase by DISCOs + 20% (assumed) distribution margin and tariff paid by the consumers
		*iii) to compute average cost of electricity provision; calcualtion is as follows; 
	
					Consumption slab				Price (NIS per KWH)			Subsidy (NIS per kWh) difference between tariff and cost (NIS 0.636)		
		
			Between 1 and 160 KWH per month				0.458						0.178
			Between 161 and 250 KWH per month			0.4938						0.1422
			Between 251 and 400 KWH per month			0.5695						0.0665
			Between 401 and 600 KWH per month			0.6089						0.0271
			More than 600 KWH per month					0.6731					   -0.0371
			Source: WB estimates based on range of cost of provision, and tariffs from various reports		

*Limitations: 	*it is assumed that cost of provision of electricity by all DISCOs to all the domestic consumer is NIS 0.636
				*it is assumed that this cost does not include any circular debt, maintenance cost and arrears and leakages
				*it is assumed that price of electricity (paid by the consumer) is without any component of fixed cost 
				*it is assumed that the subsidy did not change throughout the year and cost remains the same

*2.1: DIRECT EFFECTS
*/
*-------------------------------------------------------------------------------

local average_cost = 0.636		

#delimit ;
matrix input sub_el =
(
0.178 \
0.1422 \
0.0665 \
0.0271 \
-0.0371 
);
#delimit cr

gen subsidy_el=0

	
replace subsidy_el = qt_ele_ann*sub_el[1,1] if slab==1
replace subsidy_el = qt_ele_ann*sub_el[2,1] if slab==2
replace subsidy_el = qt_ele_ann*sub_el[3,1] if slab==3
replace subsidy_el = qt_ele_ann*sub_el[4,1] if slab==4
replace subsidy_el = qt_ele_ann*sub_el[5,1] if slab==5
replace subsidy_el=0 if subsidy_el<0

collapse (max) slab_ele (sum) subsidy_el, by(hhid hhweight region dec)
isid hhid

save "${temppath}energy_PSE final.dta", replace

*************************************************************************************
*PART 4 Presentation: summary stats
*************************************************************************************
use "${temppath}energy_PSE final.dta", clear
collapse (sum) subsidy_el   [fw=int(hhweight)], by(region dec)
export excel using "${results}PSE_energy_2017_new2.xls", firstrow(var) sheet(Sheet1, modify)

use "${temppath}energy_PSE final.dta", clear
collapse (sum) subsidy_el [fw=int(hhweight)], by(slab_el)
export excel using "${results}PSE_energy_2017_new2.xls", firstrow(var) sheet(Sheet2, modify)

