* Palestine Fiscal Incidence Analysis
* Harmonizing the CEQ dataset 
* 16th June 2022 
* Maya Goldman 



use "${outputpath}\PSE FIA 2017_master data.dta", clear

	keep hhid hhweight hhsize region id01 cluster strata *_real* pov_line
	
* Rename variables to use the CEQ harmonized data conventions 

	ren (pen_publ_hh_real_pc con_pens_hh_real_pc con_pens_isrl_hh_real_pc con_pens_plst_hh_real_pc) (pen_publ_pc con_pens_pc con_pens_isrl_pc con_pens_plst_pc)

	ren (TOT_dirtax_real_pc dtx_pitx_hh_real_pc dtx_pitx_plst_hh_real_pc dtx_pitx_isrl_hh_real_pc prop_tax_adj_real_pc buil_tax_adj_real_pc prop_tax_land_real_pc TOT_indtax_real_pc TOT_VAT_adj_real_pc vat_ind_adj_real_pc vat_d_adj_real_pc TOT_custom_duty_real_pc custom_duty_d_real_pc custom_duty_ind_real_pc) ///
	(dtx_pc dtx_pitx_pc dtx_pitx_plst_pc dtx_pitx_isrl_pc dtx_prop_pc dtx_prop_buil_pc dtx_prop_land_pc itx_pc itx_vatx_pc itx_vati_pc itx_vatd_pc itx_cusx_pc itx_cusd_pc itx_cusi_pc)

	ren (TOT_dirtrans_real_pc govt_cashaid_total_real_pc govt_kindaid_total_real_pc TOT_indsubs_real_pc subsidy_el_real_pc TOT_fuel_sub_real_pc fuel_sub_d_real_pc fuel_sub_ind_real_pc TOT_health_transf_real_pc hospitals_health_ben_real_pc amb_health_ben_real_pc TOT_edu_transf_real_pc basic_transf_real_pc second_transf_real_pc) ///
	(dtr_pc dtr_cash_pc dtr_inkd_pc sub_pc sub_elec_pc sub_fuel_pc sub_fueld_pc sub_fueli_pc hlt_pc hlt_hosp_pc hlt_ambl_pc edu_pc edu_prim_pc edu_seco_pc)

	ren (TOT_fuel_exc_real_pc fuel_exc_d_real_pc fuel_exc_ind_real_pc) (itx_excf_pc itx_excfd_pc itx_excfi_pc)

	ren (mkty_2_real_pc mktypp_real_pc netmkty_real_pc netmkty_2_real_pc dispy_real_pc consy_real_pc finaly_real_pc) ///
	(ym_pc yp_pc yn_pc yk_pc yd_pc yc_pc yf_pc)

* Label variables according to CEQ labeling conventions 
	lab var hhsize "Household size"
	lab var pen_publ_pc "Pension income"
	lab var con_pens_pc "Pension contributions"
	lab var con_pens_isrl_pc "Pension contributions (Isrl)"
	lab var con_pens_plst_pc "Pension contributions (Plst)"

	lab var dtx_prop_pc "Property tax"
	lab var dtx_prop_buil_pc "Property tax (building)"
	lab var dtx_prop_land_pc "Property tax (land)"

	lab var dtx_pitx_pc "PIT"
	lab var dtx_pitx_isrl_pc "PIT (Isrl)"
	lab var dtx_pitx_plst_pc "PIT (Plst)"

	lab var con_pens_pc "Pension contributions"
	lab var con_pens_isrl_pc "Pension contributions (Isrl)"
	lab var con_pens_plst_pc "Pension contributions (Plst)"

	lab var itx_vatx_pc "VAT"
	lab var itx_vati_pc "VAT (indirect)"
	lab var itx_vatd_pc "VAT (direct)"

	lab var itx_cusx_pc "Customs"
	lab var itx_cusi_pc "Customs (indirect)"  //there are no indirect effects for customs - correct? 
	lab var itx_cusd_pc "Customs (direct)"

	lab var itx_excf_pc "Fuel excise"
	lab var itx_excfi_pc "Fuel excise (indirect)" 
	lab var itx_excfd_pc "Fuel excise (direct)"

	lab var dtr_cash_pc "Cash transfers"
	lab var dtr_inkd_pc "In-kind transfers"

	lab var sub_elec_pc "Electricity subsidy"
	lab var sub_fuel_pc "Fuel subsidy"
	lab var sub_fueli_pc "Fuel subsidy (indirect)"
	lab var sub_fueld_pc "Fuel subsidy (direct)"

	lab var hlt_hosp_pc "Hospital healthc."
	lab var hlt_ambl_pc "Ambulatory healthc."

	lab var edu_prim_pc "Primary educ."
	lab var edu_seco_pc "Secondary educ."

	lab var dtr_pc "Direct transfers"
	lab var dtx_pc "Direct taxes"
	lab var itx_pc "Indirect taxes"
	lab var sub_pc "Indirect subsidies"
	lab var hlt_pc "Health benefits"
	lab var edu_pc "Education benefits"


	foreach var of varlist dtx* con* pen* y*{
		assert !mi(`var')
	}

	g yg_pc = yd_pc + dtx_pc 
	g yr_pc = yd_pc + dtx_pc + con_pens_pc
	g ye_pc = ym_pc + pen_publ_pc - con_pens_pc
	g yl_pc = yp_pc - pen_publ_pc + con_pens_pc
	replace yl_pc = 0 if yl_pc < 0 

	lab var yl_pc "Market income (PDI)"
	lab var ym_pc "Market income (PGT)"
	lab var yp_pc "Market income + pensions (PDI)"
	lab var ye_pc "Market income + pensions (PGT)"
	lab var yg_pc "Gross income (PDI)"
	lab var yr_pc "Gross income (PGT)"
	lab var yn_pc "Net market income (PDI)"
	lab var yk_pc "Net market income (PGT)"
	lab var yd_pc "Disposable income"
	lab var yc_pc "Consumable income"
	lab var yf_pc "Final income"

	foreach t in l m p e g r n k d c f{
		assert !mi(y`t'_pc) & (y`t'_pc >= 0)
	}

	g pcweight = hhweight*hhsize
	qui sum pcweight
	disp r(sum)/1e6

	save "${outputpath}\PSE FIA 2017_master data_harm.dta", replace
	use "${outputpath}\PSE FIA 2017_master data_harm.dta", clear

	g chk_yn_pc = (yd_pc - dtr_pc )
	g chk_yk_pc = (yd_pc - dtr_pc - pen_publ_pc)
	g chk_ym_pc = (yk_pc + dtx_pc + con_pens_pc )
	g chk_yp_pc = (yn_pc + dtx_pc)

	compare chk_yn_pc yn_pc if yn_pc != 0 
	compare chk_yk_pc yk_pc if yk_pc != 0 
	assert !mi(yn_pc) & !mi(yk_pc)
	compare chk_ym_pc ym_pc if ym_pc != 0 
	compare chk_yp_pc yp_pc if yp_pc != 0 



	//This all looks good... 


* Generate totals for the C1 tab 
************************************************************************

use "${outputpath}\PSE FIA 2017_master data.dta", clear
	
	drop *_real_pc
	ren (*_hh_pc) (*_pc)

	
	
	keep hhid hhweight region id01 hhsize cluster strata popw *_pc*

	* Rename variables to use the CEQ harmonized data conventions 
	*** Note: we use nominal, not real variables, to calculate the C1 totals ***

	ren (pen_publ_pc con_pens_pc con_pens_isrl_pc con_pens_plst_pc) (pen_publ_pc con_pens_pc con_pens_isrl_pc con_pens_plst_pc)

	ren (TOT_dirtax_pc dtx_pitx_pc dtx_pitx_plst_pc dtx_pitx_isrl_pc prop_tax_adj_pc buil_tax_adj_pc prop_tax_land_pc TOT_indtax_pc TOT_VAT_adj_pc vat_ind_adj_pc vat_d_adj_pc TOT_custom_duty_pc custom_duty_d_pc custom_duty_ind_pc) ///
	(dtx_pc dtx_pitx_pc dtx_pitx_plst_pc dtx_pitx_isrl_pc dtx_prop_pc dtx_prop_buil_pc dtx_prop_land_pc itx_pc itx_vatx_pc itx_vati_pc itx_vatd_pc itx_cusx_pc itx_cusd_pc itx_cusi_pc)

	ren (TOT_dirtrans_pc govt_cashaid_total_pc govt_kindaid_total_pc TOT_indsubs_pc subsidy_el_pc TOT_fuel_sub_pc fuel_sub_d_pc fuel_sub_ind_pc TOT_health_transf_pc hospitals_health_ben_pc amb_health_ben_pc TOT_edu_transf_pc basic_transf_pc second_transf_pc) ///
	(dtr_pc dtr_cash_pc dtr_inkd_pc sub_pc sub_elec_pc sub_fuel_pc sub_fueld_pc sub_fueli_pc hlt_pc hlt_hosp_pc hlt_ambl_pc edu_pc edu_prim_pc edu_seco_pc)

	ren (TOT_fuel_exc_pc fuel_exc_d_pc fuel_exc_ind_pc) (itx_excf_pc itx_excfd_pc itx_excfi_pc)

	*** Replace the values for East Jerusalem to 0 for all instruments 
	
	drop if id01==40|id01==41

	ren (mkty_2_pc mktypp_pc netmkty_pc netmkty_2_pc dispy_pc consy_pc finaly_pc) ///
	(ym_pc yp_pc yn_pc yk_pc yd_pc yc_pc yf_pc)

	g yg_pc = yd_pc + dtx_pc 
	g yr_pc = yd_pc + dtx_pc + con_pens_pc
	g ye_pc = ym_pc + pen_publ_pc - con_pens_pc
	g yl_pc = yp_pc - pen_publ_pc + con_pens_pc
	replace yl_pc = 0 if yl_pc < 0

	collapse (sum) pen_* con_* dtx_* itx_* dtr_* sub_* hlt_* edu_* y* [pw=popw]

	foreach i of varlist *{  
		replace `i' = -`i' if `i' < 0 
	}  

	lab var pen_publ_pc "Pension income"
	lab var con_pens_pc "Pension contributions"
	lab var con_pens_isrl_pc "Pension contributions (Isrl)"
	lab var con_pens_plst_pc "Pension contributions (Plst)"

	lab var dtx_prop_pc "Property tax"
	lab var dtx_prop_buil_pc "Property tax (building)"
	lab var dtx_prop_land_pc "Property tax (land)"

	lab var dtx_pitx_pc "PIT"
	lab var dtx_pitx_isrl_pc "PIT (Isrl)"
	lab var dtx_pitx_plst_pc "PIT (Plst)"

	lab var con_pens_pc "Pension contributions"
	lab var con_pens_isrl_pc "Pension contributions (Isrl)"
	lab var con_pens_plst_pc "Pension contributions (Plst)"

	lab var itx_vatx_pc "VAT"
	lab var itx_vati_pc "VAT (indirect)"
	lab var itx_vatd_pc "VAT (direct)"

	lab var itx_cusx_pc "Customs"
	lab var itx_cusi_pc "Customs (indirect)"  //there are no indirect effects for customs - correct? 
	lab var itx_cusd_pc "Customs (direct)"

	lab var itx_excf_pc "Fuel excise"
	lab var itx_excfi_pc "Fuel excise (indirect)" 
	lab var itx_excfd_pc "Fuel excise (direct)"

	lab var dtr_cash_pc "Cash transfers"
	lab var dtr_inkd_pc "In-kind transfers"

	lab var sub_elec_pc "Electricity subsidy"
	lab var sub_fuel_pc "Fuel subsidy"
	lab var sub_fueli_pc "Fuel subsidy (indirect)"
	lab var sub_fueld_pc "Fuel subsidy (direct)"

	lab var hlt_hosp_pc "Hospital healthc."
	lab var hlt_ambl_pc "Ambulatory healthc."

	lab var edu_prim_pc "Primary educ."
	lab var edu_seco_pc "Secondary educ."

	lab var dtr_pc "Direct transfers"
	lab var dtx_pc "Direct taxes"
	lab var itx_pc "Indirect taxes"
	lab var sub_pc "Indirect subsidies"
	lab var hlt_pc "Health benefits"
	lab var edu_pc "Education benefits"

	lab var yl_pc "Market income (PDI)"
	lab var ym_pc "Market income (PGT)"
	lab var yp_pc "Market income + pensions (PDI)"
	lab var ye_pc "Market income + pensions (PGT)"
	lab var yg_pc "Gross income (PDI)"
	lab var yr_pc "Gross income (PGT)"
	lab var yn_pc "Net market income (PDI)"
	lab var yk_pc "Net market income (PGT)"
	lab var yd_pc "Disposable income"
	lab var yc_pc "Consumable income"
	lab var yf_pc "Final income"


	
	export excel using "${outputpath}c1.xlsx", firstrow(varlabels) sheet(c1) sheetmodify
	save "${outputpath}c1.dta", replace
