**************************************************************************************************************************************************************
* West Bank & Gaza
* Code to produce results for Powerpoint and report 
* Maya Goldman
* 10 November 2022 

set type double 

*Part 1 

* File paths 

use "${outputpath}PSE FIA 2017_master data_harm.dta", clear 

*drop if id01==40|id01==41  
	/* uncomment this out if you want to exclude EJ - problem is that then poverty headcount and 
		Gini won't match the official numbers. */

g dtx_pitx_west_pc = 0 
replace dtx_pitx_west_pc = dtx_pitx_pc if region == 1
 g dtx_pitx_gaza_pc = 0 
replace dtx_pitx_gaza_pc = dtx_pitx_pc if region == 2
g dtx_pitx_east_pc = 0 
replace dtx_pitx_east_pc = dtx_pitx_pc if region == 3

qui sum dtx_pitx_pc [w=pcweight]
disp r(sum)/1e6
qui sum dtx_pitx_west_pc [w=pcweight]
disp r(sum)/1e6
qui sum dtx_pitx_gaza_pc [w=pcweight]
disp r(sum)/1e6
qui sum dtx_pitx_east_pc [w=pcweight]
disp r(sum)/1e6

listsome dtx_pitx_pc dtx_pitx_west_pc dtx_pitx_gaza_pc
	
	*qui sum pcweight
	*disp r(sum)/1e6

	sort hhid 

***************************************************************************************************************************************************************
** 0. Preparation
***************************************************************************************************************************************************************
	
* Calculate population 
	global pop_mil = r(sum)/1e6  
		//4.95 mil 

* Poverty lines 
	ren pov_line pl_nat
	g pl_190 = 5.2*365
	g pl_320 = 8.7*365
	g pl_550 = 15*365

	//Source: https://databankfiles.worldbank.org/public/ddpext_download/poverty/33EF03BB-9722-4AE2-ABC7-AA2972D68AFE/Global_POVEQ_PSE.pdf

	global cnv 2.71875 //see _pov_intl.do for more info. This is the only conversion rate which gives accurate numbers at all three lines. 
	disp $cnv

	*g pl_190 = 1.90*$cnv*365
	*g pl_320 = 3.20*$cnv*365
	*g pl_550 = 5.50*$cnv*365

* Calculate totals for each category of instrument, and generate the net benefit variables 
	*egen dtr_pc = rowtotal(pen_publ_pc dtr_cash_pc dtr_inkd_pc)
	*egen dtx_pc = rowtotal(dtx_pitx_pc dtx_prop_pc)
	egen con_pc = rowtotal(con_pens_pc)
	*egen itx_pc = rowtotal(itx_vatx_pc itx_cusx_pc)
	*gene sub_pc = rowtotal(sub_elec_pc sub_fuel_pc)  //no subsidies for the moment but we add it in here as a placeholder so that the code runs 
	*egen fee_pc = rowtotal(fee_educ_pc fee_hlth_pc)
	*egen hlt_pc = rowtotal(hlt_hosp_pc hlt_ambl_pc)
	*egen edu_pc = rowtotal(edu_prim_pc edu_seco_pc)
	egen ink_pc = rowtotal(hlt_pc edu_pc) 

	save "${outputpath}etabs.dta", replace 
  


* Set locals 
	
	loc itxlist itx_pc itx_vatx_pc itx_vatd_pc itx_vati_pc itx_cusx_pc itx_cusd_pc itx_excf_pc itx_excfd_pc itx_excfi_pc
	loc dtxlist dtx_pc dtx_pitx_pc dtx_pitx_plst_pc dtx_pitx_isrl_pc dtx_prop_pc dtx_prop_buil_pc dtx_prop_land_pc
	loc conlist con_pc con_pens_pc con_pens_plst_pc con_pens_isrl_pc 
	loc feelist // fee_pc fee_hlth_pc fee_educ_pc
	
	loc dtrlist dtr_pc pen_publ_pc dtr_cash_pc dtr_inkd_pc
	loc sublist sub_pc sub_elec_pc sub_fuel_pc sub_fueli_pc sub_fueld_pc
	loc inklist ink_pc hlt_pc hlt_ambl_pc hlt_hosp_pc edu_pc edu_prim_pc edu_seco_pc
	
	loc paylist `itxlist' `dtxlist' `conlist' `feelist'
	loc benlist `dtrlist' `sublist' `inklist'
	
	loc fisclist `dtxlist' `conlist' `dtrlist' `itxlist' `sublist' `inklist' `feelist' 
	loc inclist ym yp yn yd yc yf
	loc incpclist ym_pc yp_pc yn_pc yd_pc yc_pc yf_pc
	loc othrlist 

* Generate the deciles 
	foreach y of local inclist{
		quantiles `y'_pc [aw=pcweight], nq(10) gencatvar(dec_`y')  //Creating the decile variable: Note yp_pc is the pre-fiscal income	
	}


* Replace all the tax variables with negatives
	
	foreach t of local paylist{
		replace `t' = -`t' 
	}
	assert itx_pc <= 0 & dtx_pc <= 0 & con_pc <= 0 // & fee_pc <= 0
	
	egen net_cash_pc = rowtotal(dtx_pc itx_pc dtr_pc sub_pc)  
	egen net_totl_pc = rowtotal(net_cash_pc ink_pc) 
	loc netlist net_cash_pc net_totl_pc
	loc fiscinclist `fisclist' `incpclist' `netlist' `othrlist'

* Calculate baseline poverty and inequality for all income concepts 
	foreach i of local inclist{ 
		qui ineqdeco `i'_pc [w=pcweight]                        // creating base inequality
		gen gi_`i'_pc = r(gini)*100

		qui povdeco `i'_pc [w=pcweight], varpl(pl_nat)   // used different weights than you used. I could not find pcweighteights. Also, I used national poverty lines, is this correct. - correct. pcweighteights = pcweights. same thing. 
		g ph_`i'_pc = r(fgt0)*100
		g pg_`i'_pc = r(fgt1)*100
	}

	tempfile prep 
	save `prep'  

	global kkw_y yp_pc 
	global inc_y yp_pc 
		//MG: I am saving the dataset here as a temporary file so that I don't need to create the deciles again down-below. 
			//We should always avoid doing the same thing twice as that is where errors can creep in if we come and edit the code later and we edit the code up-top but not down below - make sense? 	

***************************************************************************************************************************************************************
* Outputs
***************************************************************************************************************************************************************
* 1. Gini and Poverty 
***************************************************************************************************************************************************************


// 1a) PDI
	
	rename (yp_pc yn_pc yd_pc yc_pc yf_pc) (pdi1 pdi2 pdi3 pdi4 pdi5) 
	foreach i of numlist 1/5 {     
		qui ineqdeco pdi`i' [w=pcweight]                                  //Calculating inequality
		gen gi_pdis_`i' = r(gini)*100                             // Generating inequality/Gini
	
		qui povdeco pdi`i' [w=pcweight], varpl(pl_nat)                // Calculating poverty based on the national poverty line
		gen ph_natl_pdis_`i' = r(fgt0)*100                              // generating the headcount ratio
		gen pg_natl_pdis_`i' = r(fgt1)*100                              // generating the average normalised poverty gap 
	
		qui povdeco pdi`i' [w=pcweight], varpl(pl_190)                // Calculating poverty based on the international poverty line ($3.20 per person per day)
		gen ph_intl_pdis190_`i' = r(fgt0)*100                              
		gen pg_intl_pdis190_`i' = r(fgt1)*100

		qui povdeco pdi`i' [w=pcweight], varpl(pl_320)                // Calculating poverty based on the international poverty line ($3.20 per person per day)
		gen ph_intl_pdis320_`i' = r(fgt0)*100                              
		gen pg_intl_pdis320_`i' = r(fgt1)*100

		qui povdeco pdi`i' [w=pcweight], varpl(pl_550)                // Calculating poverty based on the international poverty line ($5.50 per person per day)
		gen ph_intl_pdis550_`i' = r(fgt0)*100                              
		gen pg_intl_pdis550_`i' = r(fgt1)*100
	} 


// 1b) PGT
	
	rename (ym_pc yk_pc pdi3 pdi4 pdi5) (pgt1 pgt2 pgt3 pgt4 pgt5)
	foreach i of numlist 1/5 {                     // (m= market income; k= net income; d = disposable income; c = consumable income; f = final income) 
		qui ineqdeco pgt`i'[w=pcweight]                              // Calculating inequality  
		gen gi_pgts_`i' = r(gini)*100
	
	
		qui povdeco pgt`i' [w=pcweight], varpl(pl_nat)              // Calculating poverty based on the national poverty line
		gen ph_natl_pgts_`i' = r(fgt0)*100                            // generating the headcount ratio
		gen pg_natl_pgts_`i' = r(fgt1)*100

		qui povdeco pgt`i' [w=pcweight], varpl(pl_190)                // Calculating poverty based on the international poverty line ($3.20 per person per day)
		gen ph_intl_pgts190_`i' = r(fgt0)*100                              
		gen pg_intl_pgts190_`i' = r(fgt1)*100

		qui povdeco pgt`i' [w=pcweight], varpl(pl_320)                // Calculating poverty based on the international poverty line ($3.20 per person per day)
		gen ph_intl_pgts320_`i' = r(fgt0)*100                              
		gen pg_intl_pgts320_`i' = r(fgt1)*100

		qui povdeco pgt`i' [w=pcweight], varpl(pl_550)                // Calculating poverty based on the international poverty line ($5.50 per person per day)
		gen ph_intl_pgts550_`i' = r(fgt0)*100                              
		gen pg_intl_pgts550_`i' = r(fgt1)*100                             
	}

// 1c) Total impact 

	foreach sc in pdis pgts{
		g gi_`sc'_6 = gi_`sc'_1 - gi_`sc'_5	
	}
	global fi_gini gi_pgts_6
	

	foreach sc in natl_pdis intl_pdis190 intl_pdis320 intl_pdis550  natl_pgts intl_pgts190 intl_pgts320 intl_pgts550{
		g ph_`sc'_6 = ph_`sc'_1 - ph_`sc'_4
		g pg_`sc'_6 = pg_`sc'_1 - pg_`sc'_4
	}
	global fi_pov ph_intl_pdis320_6
	disp $fi_gini
	disp $fi_pov


 
	collapse (mean) gi_* ph_* pg_* 

	g id = _n 
	reshape long gi_pdis_ gi_pgts_ ph_natl_pdis_ ph_intl_pdis190_ ph_intl_pdis320_ ph_intl_pdis550_ ///
									pg_natl_pdis_ pg_intl_pdis190_ pg_intl_pdis320_ pg_intl_pdis550_ ///
	  								ph_natl_pgts_ ph_intl_pgts190_ ph_intl_pgts320_ ph_intl_pgts550_ ///
	  								pg_natl_pgts_ pg_intl_pgts190_ pg_intl_pgts320_ pg_intl_pgts550_, i(id) j(y)
	ren (*_) (*)

	lab def y_lvl 1 "Pre-fiscal" 2"Net market" 3"Disposable" 4"Consumable" 5"Final" 6"Total redistributive effect"
	lab val y y_lvl
	lab var y "Income type" 
	lab var gi_pdis "Gini (PDI)"
	lab var gi_pgts "Gini (PGT)"
	lab var ph_natl_pdis "Nat. pov. headc. (PDI)"
	lab var ph_intl_pdis190 "$1.90 pov. headc. (PDI)"
	lab var ph_intl_pdis320 "$3.20 pov. headc. (PDI)"
	lab var ph_intl_pdis550 "$5.50 pov. headc. (PDI)"
	lab var pg_natl_pdis "Nat. pov. gap (PDI)"
	lab var pg_intl_pgts190 "$1.90 pov. gap (PGT)"
	lab var pg_intl_pgts320 "$3.20 pov. gap (PGT)"
	lab var pg_intl_pgts550 "$5.50 pov. gap (PGT)"
	lab var ph_natl_pgts "Nat. pov. headc. (PGT)"
	lab var pg_natl_pgts "Nat. pov. gap (PGT)"

	foreach i of varlist gi* ph* pg*{
		g `i'_ch = `i'[_n-1] - `i'[_n]
		replace `i'_ch = `i' if inlist(y,1,6)
		replace `i'_ch = `i'_ch
	}

	save "${outputpath}gini_pov.dta", replace


*************************************************************************************************************************************************************************
** 2. Fiscal Impoverishment / Fiscal Gains to the Poor 
*************************************************************************************************************************************************************************
/* 
a. Fiscal impoverishment: An individual who is poor at post-fiscal income is made poorer by the fiscal system or when an individual who is not poor at pre-fiscal income is 
	made poor at consumable income by the fiscal system. 
b. Fiscal gains to the poor: An individual who is poor at pre-fiscal income experiences gains in income due to the fiscal system. 

*/

use `prep', clear
keep hhid pcweight pl_nat ym_pc yk_pc yn_pc yd_pc yc_pc yf_pc 


* p382 of the 2018 handbook: 1/n * SUM 1(y1 - y0)*1(y1 - z), where z if the poverty line, y1 is post-fiscal income, and y0 is pre-fiscal income 
* PGT
	g poor_0 = (ym_pc < pl_nat)
	g poor_1 = (yk_pc < pl_nat) 
	g poor_2 = (yd_pc < pl_nat) 
	g poor_3 = (yc_pc < pl_nat)

	g fi_0 = (poor_0 == 1 & ym_pc < ym_pc)
	g fi_1 = (poor_1 == 1 & yk_pc < ym_pc)
	g fi_2 = (poor_2 == 1 & yd_pc < ym_pc)
	g fi_3 = (poor_3 == 1 & yc_pc < ym_pc)

	g fg_0 = (poor_0 == 1 & ym_pc > ym_pc)
	g fg_1 = (poor_0 == 1 & yk_pc > ym_pc)
	g fg_2 = (poor_0 == 1 & yd_pc > ym_pc)
	g fg_3 = (poor_0 == 1 & yc_pc > ym_pc)

* Values 
* PGT

* Fiscal impoverishment: poor and made poorer relative to market income 

	g fi_pc_0 = (min(ym_pc,pl_nat) - min(ym_pc,ym_pc,pl_nat)) if  fi_0 == 1 //  poor_0 == 1 &  (ym_pc < ym_pc)
	g fi_pc_1 = (min(ym_pc,pl_nat) - min(ym_pc,yk_pc,pl_nat)) if  fi_1 == 1 //  poor_1 == 1 &  (yk_pc < ym_pc)
	g fi_pc_2 = (min(ym_pc,pl_nat) - min(ym_pc,yd_pc,pl_nat)) if  fi_2 == 1 //  poor_2 == 1 &  (yd_pc < ym_pc)
	g fi_pc_3 = (min(ym_pc,pl_nat) - min(ym_pc,yc_pc,pl_nat)) if  fi_3 == 1 //  poor_3 == 1 &  (yc_pc < ym_pc)

	g fg_pc_0 = (min(ym_pc,pl_nat) - min(ym_pc,ym_pc,pl_nat)) if fg_0 == 1 // poor_0 == 1 & (ym_pc > ym_pc)
	g fg_pc_1 = (min(yk_pc,pl_nat) - min(ym_pc,yk_pc,pl_nat)) if fg_1 == 1 // poor_0 == 1 & (yk_pc > ym_pc)
	g fg_pc_2 = (min(yd_pc,pl_nat) - min(ym_pc,yd_pc,pl_nat)) if fg_2 == 1 // poor_0 == 1 & (yd_pc > ym_pc)
	g fg_pc_3 = (min(yc_pc,pl_nat) - min(ym_pc,yc_pc,pl_nat)) if fg_3 == 1 // poor_0 == 1 & (yc_pc > ym_pc)

	browse fi_pc_1 pl_nat ym_pc yk_pc if fi_pc_1 > 0 


	mvencode fi_pc_* fg_pc_*, mv(.=0)

	assert fg_1 == 0  
	
	g n = 1 

	order hhid 

	qui sum fi_pc_1 [w=pcweight]
	disp r(sum)
	
	collapse (sum) n poor_* fi_* fg_* [pw=(pcweight)]
	reshape long fi_ fi_pc_ fg_ fg_pc_ poor_, i(n) j(income) 
	ren (*_) (*)
	ren (*pc*) (*tt*)
	lab define income_lbl 0"Market" 1"Net market" 2"Disposable" 3"Consumable"
	lab val income income_lbl  

	lab var fi "Number fiscally impoverished"
	lab var fi_tt "Total fiscal impoverishment"

	lab var fg "Number fiscally gaining"
	lab var fg_tt "Total fiscal gains"

	g prepoor = poor[1]
	ren poor postpoor 

	g fi_poor = -(fi/postpoor)*100
	g fi_pc_poor = -(fi_tt/postpoor)/12

	g fg_poor = (fg/prepoor)*100
	g fg_pc_poor = (fg_tt/prepoor)/12

	lab var fi_pc_poor "Average FI for the poor (monthly, LCU)"
	lab var fg_pc_poor "Average FGP (monthly, LCU)"

	g fi_pop = -(fi/n)*100
	g fi_pc_pop = -fi_tt/n

	g fg_pop = (fg/n)*100
	g fg_pc_pop = fg_tt/n

	br income fi_pc_pop fg_pc_pop fi_pc_poor fg_pc_poor fi_tt fg_tt

	export excel using "${outputpath}FIdataset.xlsx", first(varlabels) sheetmodify
	save "${outputpath}fiscimp.dta", replace


*************************************************************************************************************************************************************************
** 2. Concentration coefficient
*************************************************************************************************************************************************************************
/* 	1. Concentration indices are frequently used to measure inequality in one variable over the distribution of another. 
	2. Negative no. for a transfer means, as a % of income, a proportional transfer will add more to a poor person's income than a rich person’s
	3. Positive no. as a % of income, a proportional transfer will add more to a poor person's income than a rich person’s */
*
	/* A concentration coefficient less than zero indicates that the variable in question is most concentrated at the bottom end of the income distribution (Poor)
	being used to rank households; a concentration coefficient equal to zero indicates that the variable in question is evenly spread across the 
		income distribution; and a concentration coefficient greater than zero indicates that the variable in question is concentrated at the top end of the 
			(ranking) income distribution (rich).*/

use `prep', clear 

foreach y in ym yd yc{
	foreach i of local fisclist{
		qui concindexi `i' [aw=pcweight], welfarevar(`y'_pc) clean
		matselrc r(CII) C_`y', row(1) col(1)
		g cc_`y'_`i' = C_`y'[1,1]*100
		matrix list C_`y'
	}

**********************************************************************************************************************************************************************88
** 3. Kakwani Coefficient 
*************************************************************************************************************************************************************************
/*	A positive value indicates progressivity, a negative value indicates regressivity, and a value of 0 indicates a distributionally neutral tax or transfer. */
** 5.a. Transfers (Gini Coefficient - Concentration coefficient)

	foreach i of local benlist{
		g kk_`y'_`i' = gi_`y'_pc - cc_`y'_`i'
	}

** 5.b. Taxes (Concentration coefficient - Gini Coefficient)
	foreach i of local paylist{
		g kk_`y'_`i' = cc_`y'_`i' - gi_`y'_pc
	}
}

***************************************************************************************************************************************************************************
** 4. Marginal Contributions 
***************************************************************************************************************************************************************************
/*	The Marginal Contribution of a fiscal instrument is measured by the difference in an inequality or poverty measure (or any other distributional statistic)
		 at any Postfiscal Income and the Gini coefficient at the same Postfiscal Income concept excluding the instrument in question.  

/* Logic: 
	a. Generate a Gini at "End income". 
	b. End income should be market income for direct taxes and transfers, disposable income for indirect taxes and subsidies, 
		and consumable income for the in-kind benefits. 
	c. Then, create a Gini at End income excluding the variable in question). 
	d. After this, subtract the latter from the former.
	e. Interpretation: neg. marginal contribution means decreases inequality; pos. means increases inequality (this seems more intuitive) */
*/

loc ymlist    //variables included in market income 
	loc noymlist `dtxlist' `conlist' `dtrlist' `itxlist' `sublist' `inklist' `feelist' //variable NOT included in market income

loc ydlist  `dtxlist' `conlist' `dtrlist'  //variables included in disposable income 
	loc noydlist  `itxlist' `sublist' `inklist' `feelist' //variable NOT included in disposable income

loc yclist `dtxlist' `conlist' `dtrlist' `itxlist' `sublist'  //all variables included in consumable income 
	loc noyclist `inklist' `feelist'												 //all variables NOT included in consumable income

foreach y in m d c{
// Calculate consumable income with / without the variable of interest 
	foreach i of local y`y'list{
		g y`y'_`i' = y`y'_pc - `i' 
	}  
	*listsome yc_pc yc_itx_vatx_pc
		//this removes the direct transfers and adds in the taxes 

	foreach i of local noy`y'list{
		g y`y'_`i' = y`y'_pc + `i'
	}

	

/*
		g ym_dtr_cash_pc = ym_pc + dtr_cash_pc
		qui povdeco ym_pc [w=pcweight], varpl(pl_nat)   
		*g ph_ym_pc = r(fgt0)*100
		qui povdeco ym_dtr_cash_pc [w=pcweight], varpl(pl_nat)   
		g ph_ym_dtr_cash_pc = r(fgt0)*100

		g mc_ym_dtr_cash_pc = ph_ym_dtr_cash_pc - ph_ym_pc
		tab mc_ym_dtr_cash_pc
		//this adds in the in-kind transfers and removes the user-fees 
	*/
// Calculate inequality for the extended consumable income concepts
	
	foreach i of local fisclist{
		qui ineqdeco y`y'_`i' [w=pcweight]
		g gi_y`y'_`i' = r(gini)*100

		qui povdeco y`y'_`i' [w=pcweight], varpl(pl_nat)   
		g ph_y`y'_`i' = r(fgt0)*100
		g pg_y`y'_`i' = r(fgt1)*100
	}

	
* Calculate marginal contributions as the value with the variable less the value without 
	//  For all instruments except education and health, the generated variable is w/o the instrument 
	foreach i of local y`y'list{
		g mc_gi_y`y'_`i' = (gi_y`y'_`i' - gi_y`y'_pc)
		g mc_ph_y`y'_`i' = (ph_y`y'_`i' - ph_y`y'_pc)
		g mc_pg_y`y'_`i' = (pg_y`y'_`i' - pg_y`y'_pc)
	}


* For taxes, education and health 
	foreach i of local noy`y'list{
		g mc_gi_y`y'_`i' = (gi_y`y'_pc - gi_y`y'_`i')
		g mc_ph_y`y'_`i' = (ph_y`y'_pc - ph_y`y'_`i')
		g mc_pg_y`y'_`i' = (pg_y`y'_pc - pg_y`y'_`i')
	}
		//if you ADD the variable and the gini goes up, then the MC is negative 
 }

 * Check that the marginal contribution of the PIT at market income is the gini at market inomce 
assert ym_dtx_pitx_pc <= ym_pc
assert ym_dtx_pitx_plst_pc <= ym_pc
assert !mi(ym_dtx_pitx_plst_pc) & !mi(ym_dtx_pitx_isrl_pc)
assert ym_dtx_pitx_pc == (ym_pc + dtx_pitx_pc)  //spotcheck 
 assert ym_dtx_pitx_plst_pc == (ym_pc + dtx_pitx_plst_pc)  //spotcheck 
 assert ym_dtx_pitx_pc == (ym_pc + dtx_pitx_pc)  //spotcheck 
 assert mc_gi_ym_dtx_pitx_pc == (gi_ym_pc - gi_ym_dtx_pitx_pc)
 assert mc_ph_ym_dtx_pitx_plst_pc == (ph_ym_pc - ph_ym_dtx_pitx_plst_pc)
 assert ph_yd_itx_excfi_pc >= ph_yd_itx_excfd_pc
 assert mc_ph_yd_itx_excfd_pc == (ph_yd_pc - ph_yd_itx_excfd_pc)
 assert mc_ph_yd_itx_excfi_pc == (ph_yd_pc - ph_yd_itx_excfi_pc)
 listsome ph_yd_pc mc_ph_yd_itx_excfd_pc ph_yd_itx_excfd_pc mc_ph_yd_itx_excfi_pc ph_yd_itx_excfi_pc
 
 assert mc_ph_yd_itx_excfd_pc >= mc_ph_yd_itx_excfi_pc

	collapse (mean) cc* gi* kk* ph* pg* mc*
	drop gi_* ph_* pg_*

//reshape long so that you have the variable on the rows, and the type of indicator on the columns 
	g id = _n 
	loc indlist mc_gi_ym mc_ph_ym mc_pg_ym mc_gi_yd mc_ph_yd mc_pg_yd mc_gi_yc mc_ph_yc mc_pg_yc cc_ym cc_yc cc_yd kk_ym kk_yc kk_yd
	foreach ind of local indlist{
		loc n = 1
		foreach var of local fisclist{
			ren (`ind'_`var') (`ind'_`n')
			loc n = `n'+1
		}
	} 
	reshape long mc_gi_ym_ mc_ph_ym_ mc_pg_ym_ mc_gi_yd_ mc_ph_yd_ mc_pg_yd_ mc_gi_yc_ mc_ph_yc_ mc_pg_yc_ cc_ym_ cc_yd_ cc_yc_ kk_ym_ kk_yd_ kk_yc_, i(id) j(instrument)
	ren (*_) (*)

	* Create labels for fiscal instrument dataset 
	disp "`fisclist'"

	/* 
	dtx_pc dtx_pitx_pc dtx_pitx_gaza_pc dtx_pitx_west_pc dtx_prop_pc dtx_prop_buil_pc dtx_prop_lan
 d_pc con_pc con_pens_pc con_pens_plst_pc con_pens_isrl_pc dtr_pc pen_publ_pc dtr_cash_pc dtr
 _inkd_pc itx_pc itx_vatx_pc itx_vatd_pc itx_vati_pc itx_cusx_pc itx_cusd_pc itx_excf_pc itx_
 excfd_pc itx_excfi_pc sub_pc sub_elec_pc sub_fuel_pc sub_fueli_pc sub_fueld_pc ink_pc hlt_pc
  hlt_ambl_pc hlt_hosp_pc edu_pc edu_prim_pc edu_seco_pc
*/

	lab def inst_lbl ///
			1"Direct taxes" 2"PIT" 3"PIT: West Bank & Gaza" 4"PIT: Israel" 5"Property" 6"Prop: Building" 7"Prop: Land"  ///
			8"Contributions" 9"Pension contributions" 10"Pension contributions: WB + Gaza" 11"Pension contributions: Israel" ///
			12"Direct transfers" 13"Pension income" 14"Cash Transfer Program (CTP)" 15"Near-cash transfers" ///
			16"Indirect taxes" 17"VAT (direct + indirect effect)" 18"VAT (direct effect)" 19"VAT (indirect effect)" 20"Customs (total)" 21"Customs (direct effect)" ///
			22"Fuel excise (total)" 23"Fuel excise (direct effect)" 24"Fuel excise (indirect effect)" ///
			25"Indirect subsidies" 26"Elec. subs. (direct effect)" 27"Fuel subs. (total)" 28"Fuel subs. (indirect effect)" 29"Fuel subs. (direct effect)" ///
			30"In-kind" 31"Health" 32"Primary healthc." 33"Hospital healthc." ///
			34"Educ." 35"Basic educ." 36"Secondary educ.", replace 
			// 26"Userfees" 32"Hlth userfees" 33"Edu userfees", replace 
	lab val instrument inst_lbl
	lab var mc_gi_ym "Marg. cont. to inequality reduction (ym)"
	lab var mc_ph_ym "Marg. cont. to pov. headc. reduction (ym)"
	lab var mc_pg_ym "Marg. cont. to pov. gap reduction (ym)"
	lab var mc_gi_yd "Marg. cont. to inequality reduction (yd)"
	lab var mc_ph_yd "Marg. cont. to pov. headc. reduction (yd)"
	lab var mc_pg_yd "Marg. cont. to pov. gap reduction (yd)"
	lab var mc_gi_yc "Marg. cont. to inequality reduction (yc)"
	lab var mc_ph_yc "Marg. cont. to pov. headc. reduction (yc)"
	lab var mc_pg_yc "Marg. cont. to pov. gap reduction (yc)"
	lab var cc_ym "Concentration coefficient (ym)"
	lab var cc_yc "Concentration coefficient (yc)"
	lab var cc_yd "Concentration coefficient (yd)"
	lab var kk_ym "Kakwani Index (ym)"
	lab var kk_yc "Kakwani Index (yc)"
	lab var kk_yd "Kakwani Index (yd)"

*	foreach var in cc_ym cc_yp cc_yd kk_ym kk_yp kk_yd mc_gi_yc mc_ph_yc mc_pg_yc{
*		replace `var' = round(`var',.1)
*	}
	
	drop id 
	g id = _n 
	order id instrument cc_ym cc_yd cc_yc kk_ym kk_yd kk_yc mc_gi_ym mc_gi_yd mc_gi_yc mc_ph_ym mc_ph_yd mc_ph_yc mc_pg_ym mc_pg_yd mc_pg_yc
	export excel using "${outputpath}AnnexC.xlsx", cell(a4) sheet("cc_ki_mc") sheetmodify

	drop id 
	save "${outputpath}cc_kk_mc.dta", replace
	

***************************************************************************************************************************************************************************** 
** Part 2: Distributional analysis 
*****************************************************************************************************************************************************************************
** 1. Incidence 
*****************************************************************************************************************************************************************************
	//a measure of distribution relative to income 

	foreach y in ym yp yd yc{ 
		use `prep', clear
		collapse (sum) pl_nat `fiscinclist' [fw=int(pcweight)], by(dec_`y')            

		foreach i of local fiscinclist{
			gen inc_`y'_`i' = (`i'/`y'_pc)*100
		}    
           
*****************************************************************************************************************************************************************************
** 2. Concentration shares 
*****************************************************************************************************************************************************************************
		
		//a measure of absolute distribution 
		
		foreach i of local fiscinclist{  
			qui sum `i'
			gen `i'_tt = r(sum)  
			gen conc_`y'_`i' = (`i'/`i'_tt)*100                             
		}
		ren dec_`y' id
		tempfile inci_conc_`y'
		save `inci_conc_`y''
	}
	
	use `inci_conc_ym'
	foreach y in yp yd{ 
		merge 1:1 id using `inci_conc_`y''
		drop _m
	}

save "${outputpath}inci_conc.dta", replace



*****************************************************************************************************************************************************************************
** End
*****************************************************************************************************************************************************************************
