********************************************************************************************************************************************************************
**Graphs 
*********************************************************************************************************************************************************************
	*set scheme white_tableau
	global titlesize small
	global barlblsize vsmall
	global notesize vsmall
	global inctype Market
	global source "Source: Authors' estimates based on PECS 2016/2017; LFS 2017."
	global decile "Deciles based on per capita pre-fiscal income ($inctype income)."

	global note_ph1 "The official national poverty headcount matches poverty at Disposable Income."
	global note_ph2 "We do not calculate poverty at Final income because we value the health and education transfers at the average cost of provision."
	global note_income "To calculate Net $inctype income from Pre-fiscal income we subtract the direct taxes; we add the Direct transfers to calculate Disposable income; we subtract the indirect taxes and add the indirect subsidies to calculate Consumable income and we add the in-kind health and education transfers to calculate Final income."
	global note_netben1 "Net cash benefit refers to the system including all direct and indirect taxes, transfers and subsidies, and excluding in-kind health and education transfers."
	global note_netben2 "Net total benefit refers to the system including all elements, including in-kind health and education transfers."
	global note_inc1 "Incidence is a measure of size and distribution relative to a reference income."
	global note_inc2 "Transfers are shown as a positive bar and taxes are shown as a negative bar."
	global note_kk1 "The Kakwani Index is a summary statistic of progressivity [>0 = progressive]." 
	global note_kk2 "It is calculated for taxes by subtracting the Gini coefficient from the concentration coefficient."
	global note_kk3 "It is calculated for transfers by subtracting the concentration coefficient from the Gini coefficient."
	global note_mc1 "Marginal contributions are calculated as the change in a poverty or inequality indicator that results with the inclusion of a tax or transfer of interest."
	global note_mc2 "Marginal contributions are estimated at Consumable income."
	global note_mc3 "A positive bar represents a reduction in poverty or inequality, while a negative bar represents an increase."
	global note_mc4 "We don't calculate contributions to poverty for in-kind subsidies."
	global note_y "Households are ranked over $inctype income"
	global note_cc1 "Concentration shares show the proportion of each tax/transfer paid by / benefitting each decile. They sum to 100%."
	global note_fi1 "Fiscal impoverishment: Percent of population i) poor at post-fiscal income and ii) made poorer by the fiscal system."
	global note_fi2 "Fiscal gains to the poor: Percent of population i) poor at pre-fiscal income and ii) experience gains in income due to the fiscal system."
	global note_fi3 "Pre-fiscal income is excluded from the graph because no fiscal impoverishment or fiscal gains can occur, by definition."
	global note_fi4 "Final income is excluded from the graph because we don’t measure changes in poverty at Final income."
	global note_fi5 "A positive bar represents the population experiencing fiscal gains, while a negative bar represents the population experiencing fiscal impoverishment."
	global note_fi6 "Sum of absolute value of bars doesn't add to 100 because percentages are calculated over poor populations at different income concepts."
	global note_fi7 "Sum of absolute value of bars doesn't add to total poverty headcount because percentages are calculated over poor populations at different income concepts."

*********************************************************************************************************************************************************************
* Poverty & inequality 
*********************************************************************************************************************************************************************

	use "${outputpath}gini_pov.dta", clear 
	
	// 1) Gini coefficient by income concept (slide 15)
	lab def y_lvl_pdi 1 "Market + pensions" 2"Net market" 3"Disposable" 4"Consumable" 5"Final" 6"Total redistributive effect", replace
	lab val y y_lvl_pdi
	graph bar gi_pdis if inrange(y,1,5), over(y) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) title("Gini coefficient by income concept (PDI scenario)", size($titlesize)) ytitle("Gini coefficient") ///
	note({break} ///
	"$source", size($notesize)) 
	graph export "${graph}gini_pdi.png", replace
	graph close 

	lab def y_lvl_pgt 1 "Market" 2"Net market" 3"Disposable" 4"Consumable" 5"Final" 6"Total redistributive effect", replace
	lab val y y_lvl_pgt
	graph bar gi_pgts if inrange(y,1,5), over(y) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) title("Gini coefficient by income concept (PGT scenario)", size($titlesize)) ytitle("Gini coefficient") ///
	note({break} ///
	"$source", size($notesize)) 
	graph export "${graph}gini_pgt.png", replace
	graph close 

	order y 
	tabstat gi_pgts_ch, by(y)
	tabstat ph_natl_pgts_ch, by(y)
	tabstat ph_intl_pgts550_ch, by(y)

	// 2)  Poverty headcount by income concept (slide 17)
	
	lab val y y_lvl_pdi	
	graph bar ph_natl_pdis pg_natl_pdis if inrange(y,1,4), over(y) blabel(bar, size($barlblsize) format(%9.1f)) title("Poverty by income concept (PDI scenario)", size($titlesize)) ytitle("Poverty (percentage points)") ///
		legend(label(1 "Headcount") label(2 "Gap") pos(6) row(1)) note({break} ///
	"$source" "Notes:" "[1] $note_ph1" "[2] $note_ph2", size($notesize)) 
	graph export "${graph}pov_pdi.png", replace
	graph close 

	lab val y y_lvl_pgt
	graph bar ph_natl_pgts pg_natl_pgts if inrange(y,1,4), over(y) blabel(bar, size($barlblsize) format(%9.1f)) title("Poverty by income concept (PGT scenario)", size($titlesize)) ytitle("Poverty (percentage points)") ///
	legend(label(1 "Headcount") label(2 "Gap") pos(6) row(1)) note({break} ///
	"$source" "Notes:" "[1] $note_ph1" "[2] $note_ph2", size($notesize)) 
	graph export "${graph}pov_pgt.png", replace
	graph close 

	graph bar ph_intl_pgts320 pg_intl_pgts320 if inrange(y,1,4), over(y) blabel(bar, size($barlblsize) format(%9.1f)) title("Poverty by income concept (PGT scenario)", size($titlesize)) ytitle("Poverty (percentage points)") ///
	legend(label(1 "Headcount") label(2 "Gap") pos(6) row(1)) note({break} ///
	"$source" "Notes:" "[1] $note_ph1" "[2] $note_ph2", size($notesize)) 
	graph export "${graph}pov_pgt_320.png", replace
	graph close 


* Annex: comparison of PDI and PGT 

	// 1) Gini coefficient by income concept (slide 15)
	lab val y y_lvl_pdi
	graph bar gi_pdis if inrange(y,1,5), bar(1,color(navy)) name(gi_pdis, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) title("Pensions as Deferred Income", size($titlesize)) ytitle("Gini coefficient (G.p.)")
	lab val y y_lvl_pgt
	graph bar gi_pgts if inrange(y,1,5), bar(1,color(navy)) name(gi_pgts, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) title("Pensions as Government Transfer", size($titlesize)) ytitle("")
	lab val y y_lvl_pdi
	graph bar ph_natl_pdis if inrange(y,1,4), bar(1,color(dkgreen)) name(ph_pdis, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) ytitle("Poverty headcount (p.p.)") 
	lab val y y_lvl_pgt
	graph bar ph_natl_pgts if inrange(y,1,4), bar(1,color(dkgreen)) name(ph_pgts, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) ytitle("") 
	lab val y y_lvl_pdi
	graph bar pg_natl_pdis if inrange(y,1,4), bar(1,color(lavender) )name(pg_pdis, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) ytitle("Poverty gap ratio (p.p.)") 
	lab val y y_lvl_pgt
	graph bar pg_natl_pgts if inrange(y,1,4), bar(1,color(lavender) )name(pg_pgts, replace) over(y) blabel(bar, size($barlblsize) format(%9.1f)) ytitle("") 
		
	graph combine gi_pdis gi_pgts ph_pdis ph_pgts pg_pdis pg_pgts, row(3) note({break} ///
	"$source", size($notesize)) 
	graph export "${graph}comp_pdi_pgt.png", replace
	graph close 

	tabstat ph_natl_pdis_ch pg_natl_pdis_ch, by(y)

*********************************************************************************************************************************************************************
* Progressivity & Marginal contributions
*************************************************************************************************************************************************************************

** 1. Kakwani index (slide 21) 
	use "${outputpath}cc_kk_mc.dta", replace
	*numlabel, add
	*tabstat kk_ym, by(instrument)

//Transfers 
	graph hbar kk_ym if inlist(instrument,13,14,15,26,27,28,29,32,33,35,36), over(instrument, sort(kk_ym)) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) ytitle("Kakwani Index w.r.t. $inctype Income") title("a. Progressivity of transfers", size($titlesize)) note({break} ///
	"$source" "Notes:" "[1] $note_kk1" "[2] $note_kk3", span size($notesize))
	graph export "${graph}kkw_trans.png", replace
	graph close 

	graph hbar kk_ym if inlist(instrument,2,5,9,17,18,19,21,22,23,24), over(instrument, sort(kk_ym)) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) ytitle("Kakwani Index w.r.t. $inctype Income") title("b. Progressivity of taxes", size($titlesize)) note({break} ///
	"$source" "Notes:" "[1] $note_kk1" "[2] $note_kk2", span size($notesize))
	graph export "${graph}kkw_tax.png", replace
	graph close 
  
*************************************************************************************************************************************************************************
	   
** 2. Marginal contributions to poverty and inequality: taxes (slide 27)
	
	graph hbar mc_gi_yc if inlist(instrument,2,5,9,13,14,15,17,18,19,21,22,23,24,26,27,28,29,32,33,35,36), over(instrument, sort(mc_gi_yc)) blabel(bar, size($barlblsize) format(%9.1f)) bargap(50) title("Inequality reduction", size($titlesize)) ///
	ytitle("Marginal contribution at Consumable income (Gini points)") note({break} ///
	"$source" "Notes:" "[1] $note_mc1" "[2] $note_mc3", span size($notesize)) 
	graph export "${graph}mc_ineq.png", replace
	graph close 

	graph hbar mc_ph_yc if inlist(instrument,2,5,9,13,14,15,17,18,19,21,22,23,24,26,27,28,29), over(instrument, sort(mc_ph_yc)) blabel(bar, size($barlblsize) format(%9.1f)) title("Poverty reduction", size($titlesize)) ytitle("Marginal contribution at Consumable income (percentage points)") ///
		legend(label(1 "Headcount") pos(6) row(1)) note({break} ///
	"$source" "Notes:" "[1] $note_mc1" "[2] $note_mc3" "[4] $note_mc4", span size($notesize)) 
	graph export "${graph}mc_pov.png", replace
	graph close



*************************************************************************************************************************************************************************
* Fiscal Impoverishment  
*************************************************************************************************************************************************************************

use "${outputpath}fiscimp", clear 
//36.7 and 30.4 

graph bar fi_poor fg_poor if income!=0, name("fi_fgp_poorpop", replace) over(income) stack title("Share of poor population", size($titlesize)) yscale(range(-100 100)) ylabel(-100 -50 0 50 100) ///
 ytitle("Percentage (%) of poor population") blabel(bar, size($barlblsize) format(%9.1f)) ///
 legend(label(1 "Fiscal Impoverishment") label(2 "Fiscal Gains to the Poor") pos(6) row(1)) 
 graph export "${graph}FIFGP_poor.png", replace
 graph close

 graph bar fi_pc_poor fg_pc_poor if income!=0, name("fi_fgp_poormean", replace) over(income) stack title("Average amount per poor population, monthly", size($titlesize)) ///
 ytitle("Average amount per poor population, monthly") blabel(bar, size($barlblsize) format(%9.1f)) ///
 legend(label(1 "Total FI") label(2 "Total FGP") pos(6) row(1))
 graph export "${graph}FIFGP_value_poor.png", replace
 graph close

 graph combine fi_fgp_poorpop fi_fgp_poormean, note({break} ///
	"$source" "Notes:" "[1] $note_fi1" "[2] $note_fi2" "[3] $note_fi3" "[4] $note_fi4" "[5] $note_fi6", span size($notesize)) 
graph export "${graph}FIFGP.png", replace
graph close 


/*
graph bar fi_pop fg_pop if income!=0, over(income) stack title("Fiscal impoverishment / Gains to the Poor", size($titlesize)) yscale(range(-50 50)) ylabel(-50 0 50) ///
yline(-36.7, lcolor(grey)) yline(-30.4, lcolor(blue)) yline(36.7, lcolor(grey)) yline(30.4, lcolor(blue)) ytitle("Percentage (%) of total population") blabel(bar, size($barlblsize) format(%9.1f)) ///
legend(label(1 "Fiscal Impoverishment") label(2 "Fiscal Gains to the Poor") pos(6) row(1)) note({break} ///
	"$source" "Notes:" "[1] $note_fi1" "[2] $note_fi2" "[3] $note_fi3" "[4] $note_fi4" "[5] $note_fi5" "[6] $note_fi7" "[7] Blue and black lines represents pre- and post-fiscal poor populations respectively.", span size($notesize))
graph export "${graph}FIFGP_pop.png", replace
graph close 
*/
* Size of the fiscal impoverishment 



*************************************************************************************************************************************************************************
* Net cash beneficiaries 
*************************************************************************************************************************************************************************
** Figure 4: Taxes and transfers as a share of pre fiscal income (slide 22)

	global dec id
	loc y ym
	
	use "${outputpath}inci_conc.dta", clear

	lab def decile_lbl 1"Poorest" 10"Richest"
	lab val id decile_lbl
	*tab id

	lab var inc_`y'_edu_pc "Education"
	lab var inc_`y'_sub_pc "Indirect subsidies"

	gen inc_dtx_itx = inc_`y'_dtx_pc + inc_`y'_itx_pc
	gen inc_dtx_itx_con = inc_`y'_dtx_pc + inc_`y'_itx_pc + inc_`y'_con_pc
	
	gen inc_dtr_sub = inc_`y'_dtr_pc + inc_`y'_sub_pc      //hlt + edu 
	gen inc_dtr_sub_hlt = inc_dtr_sub + inc_`y'_hlt_pc  //hlt + edu + dtr 
	gen inc_dtr_sub_hlt_edu = inc_dtr_sub_hlt + inc_`y'_edu_pc  //hlt + edu + dtr + indirect subsidies (currently = 0)

	lab var inc_`y'_itx_pc "Indirect taxes"
	lab var inc_dtx_itx "Direct taxes"
	lab var inc_dtx_itx_con "Contributions"

	lab var inc_dtr_sub_hlt "Health"
	lab var inc_dtr_sub_hlt_edu "Education"
	lab var inc_`y'_dtr_pc "Direct transfers"
	lab var inc_dtr_sub "Indirect subsidies"
	
	lab var inc_`y'_net_totl_pc "Net total benefit"
	lab var inc_`y'_net_cash_pc "Net cash benefit"

	global barw 0.5
	
	twoway bar inc_dtx_itx_con $dec, barw($barw)  ///
	|| bar inc_dtx_itx $dec, barw($barw)  ///
	|| bar inc_`y'_itx_pc $dec, barw($barw)  ///
	|| bar inc_dtr_sub_hlt_edu $dec, barw($barw) /// 
	|| bar inc_dtr_sub_hlt $dec, barw($barw)  ///
	|| bar inc_dtr_sub $dec, barw($barw)  ///
	|| bar inc_`y'_dtr_pc $dec, barw($barw) ///
	|| connected inc_`y'_net_totl_pc $dec ///
	|| connected inc_`y'_net_cash_pc $dec ///
	, ytitle("Percent of $inctype income") xtitle("Decile of $inctype income") xlabel(1"Poorest" 2 3 4 5 6 7 8 9 10"Richest") title("Net cash beneficiary", size($titlesize))  yline(0, lstyle(foreground)) note({break} ///
	"$source" "Notes:" "[1] $note_netben1" "[2] $note_netben2", span size($notesize))
	graph export "${graph}netcashben_line.png", replace 
	graph close 
  

*****************************************************************************************************************************************************************
* Detailed incidence graphs
*************************************************************************************************************************************************************************
	
** Taxes
	loc y ym
	graph bar inc_`y'_dtx_pitx_pc inc_`y'_dtx_prop_pc inc_`y'_con_pens_pc inc_`y'_itx_vatd_pc inc_`y'_itx_vati_pc inc_`y'_itx_cusd_pc inc_`y'_itx_excfd_pc inc_`y'_itx_excfi_pc, ///
	title("a. Incidence: taxes & contributions", size($titlesize)) over($dec, label) stack asyvars   ///
	legend(label(1 "PIT") label(2 "Property tax") label(3 "Pension contributions") label(4 "VAT (direct effect)") ///
	label(5 "VAT (indirect effect)") label(6 "Customs (direct effect)") label(7 "Fuel excise (direct effect)") ///
	label(8 "Fuel excise (indirect effect)") ///
	pos(6) row(3)) ytitle("Incidence (% of $inctype income)", size($titlesize)) note({break} ///
	"$source" "Notes:" "[1] $note_inc1" "[2] $note_inc2" "[3] $note_y", span size($notesize))
	graph export "${graph}inc_`y'_tax.png", replace 
	graph close


** Transfers
loc y ym 
	graph bar inc_`y'_pen_publ_pc inc_`y'_dtr_cash_pc inc_`y'_dtr_inkd_pc inc_`y'_sub_elec_pc inc_`y'_sub_fuel_pc inc_`y'_hlt_ambl_pc inc_`y'_hlt_hosp_pc inc_`y'_edu_prim_pc inc_`y'_edu_seco_pc, ///
	title("a. Incidence: transfers", size($titlesize)) over($dec, label) stack asyvars ///
	legend(label(1 "Pensions") label(2 "Cash Transfer Program (CTP)") label(3 "Near-cash transfers") label(4 "Elec. subs. (direct eff.)") label(5 "Fuel subs. (direct + indirect eff.)") label(6 "Primary healthc.") label(7 "Hosp. healthc.") ///
	label(8 "Basic educ.") label(9 "Seco. educ.") label(10 "Seco. educ.") ///
	pos(6) row(3)) ytitle("Incidence (% of $inctype income)", size($titlesize)) note({break} ///
	"$source" "Notes:" "[1] $note_inc1" "[2] $note_inc2" "[3] $note_y", span size($notesize))
	graph export "${graph}inc_`y'_transfer.png", replace
	graph close  

	
** Pensions and contributions 
	loc y ym
	g inc_`y'_net_pens_pc_tt = inc_`y'_pen_publ_pc + inc_`y'_con_pens_pc
	graph bar inc_`y'_pen_publ_pc inc_`y'_con_pens_pc, ///
	title("a. Incidence: pension system", size($titlesize)) over($dec, label) stack asyvars ///
	legend(label(1 "Pension income") label(2 "Pension contributions")  ///
	pos(6) row(2)) ytitle("Incidence (% of $inctype income)", size($titlesize)) note({break} ///
	"$source" "Notes:" "[1] $note_inc1" "[2] $note_inc2" "[3] $note_y", span size($notesize))
	graph export "${graph}inc_`y'_pensions.png", replace
	graph close 

	loc y ym
	twoway bar inc_`y'_pen_publ_pc $dec, barw($barw)  ///
	|| bar inc_`y'_con_pens_plst_pc $dec, barw($barw)  ///
	|| connected inc_`y'_net_pens_pc_tt $dec ///
	, ytitle("Percent of $inctype income") xtitle("Decile of $inctype income") xlabel(1"Poorest" 2 3 4 5 6 7 8 9 10"Richest") title("Net pension beneficiary", size($titlesize))  yline(0, lstyle(foreground)) note({break} ///
	"$source", span size($notesize)) legend(label(1 "Pension income") label(2 "Pension contributions") label(3 "Net benefit") pos(6) row(1))
	graph export "${graph}inc_`y'_pensions_line.png", replace 
	graph close

	*br inc_`y'_itx_pc


	*br inc_`y'_edu_* inc_`y'_hlt_* 


*****************************************************************************************************************************************************************
* Detailed concentration graphs
*************************************************************************************************************************************************************************

	*5. Concentration and incidence graphs
	*Figure 9: Tax revenue: incidence and concentration shares 
	//a) Incidence

	 global conc_ytit "Concentration shares (%)"
	 
	//b) Concentration 
	global barw2 0.2
	cap gen area1 = $dec - 0.2
	cap gen area2 = $dec
	cap gen area3 = $dec + 0.2

		loc y ym

	twoway bar conc_`y'_dtx_pc area1, barw($barw2) ///
	||     bar conc_`y'_con_pc area2, barw($barw2)  /// 
	||     bar conc_`y'_itx_pc area3, barw($barw2)  /// 
	||     connected conc_`y'_`y'_pc $dec, lpattern(dash) title("b. Concentration shares: taxes & contributions", size($titlesize)) xlabel(1"Poorest" 2 3 4 5 6 7 8 9 10"Richest") ytitle("$conc_ytit") xtitle("Decile of $inctype income") ///
	legend(pos(6) row(1) label(1 "Direct taxes") label(2 "Contributions") label(3 "Indirect taxes") label(4 "$inctype income")) yline(0, lstyle(foreground)) note({break} ///
	"$source" "Notes:" "[1] $note_cc1" "[2] $note_y", span size($notesize))
	graph export "${graph}cs_`y'_tax.png", replace
	graph close 

	global barw2 0.2
	cap gen area1 = $dec - 0.3
	cap gen area2 = $dec - 0.1
	cap gen area3 = $dec + 0.1
	cap gen area4 = $dec + 0.3

	loc y ym
	twoway bar conc_`y'_dtr_pc area1, barw($barw2) ///
	||		bar conc_`y'_sub_pc area2, barw($barw2) ///
	||     bar conc_`y'_edu_pc area3, barw($barw2)  /// 
	||     bar conc_`y'_hlt_pc area4, barw($barw2)   ///
	||     connected conc_`y'_`y'_pc $dec, lpattern(dash) title("b. Concentration shares: transfers", size($titlesize)) ytitle("$conc_ytit") xtitle("Decile of $inctype income") xlabel(1"Poorest" 2 3 4 5 6 7 8 9 10"Richest") ///
	legend(pos(6) row(1) label(1 "Direct transfers") label(2 "Indirect subsidies") label(3 "Education") label(4 "Health") label(5 "$inctype income")) yline(0, lstyle(foreground)) note({break} ///
	"$source" "Notes:" "[1] $note_cc1" "[2] $note_y", span size($notesize))
	graph export "${graph}cs_`y'_transfer.png", replace
	graph close 
   	   

**********************************************************************
* Annex A on PDI and PGT comparison
**********************************************************************

use "${temppath}PSE_pit_allvar.dta", clear 

replace pen_publ_in = 0 if pen_publ_in == . 


g pen_net_in = pen_publ_in - con_pens_in
assert con_pens_in != . & pen_publ_in != . & pen_net_in != . 

g pen_net_neg = pen_net_in < 0 
g pen_net_pos = pen_net_in > 0 

* Table A-2
collapse (sum) pen_publ_ri con_pens_pi pen_publ_tt = pen_publ_in con_pens_tt = con_pens_in [w=hhweight], by(dec) 
export excel "${outputpath}pdi_pgt.xlsx", sheet("A-2", modify) cell(b3)

**********************************************************************	   


