****************************************************
*****PALESTINE: Fiscal Incidence Analysis***********
*************World Bank, Poverty and Equity GP*********
***********TTL: Arden Finn********
**************Prepared by: Beenish Amjad***********
**************Reviewed by: Haydeeliz Carrasco***********
***********Social Protection****************************
*******************************************************
*Date: April 20, 2022

/* Notes
There are four main types of SP programs; 1- Cash Transfer Program (CTP) 2- Cash Assistance to Martyrs' Families 3- Cash Assistance to Discharged Government Employees 4- Emergency Cash Assistance (for women)
1) CTP = Largest 
		Budget=518.37 million NIS which is 63% of MoSD budget. Allocation rule = PMTF
		Process: based on PMTF score hh are sorted into categories relative to the extreme and national poverty lines. Priority=below extreme PL
		MoSD estimated the extreme poverty line at NIS 1,970 per month and the national poverty line at NIS 2,470 per month for a family of two adults and three children
		The PMTF thresholds were 6.39 (equivalent to the extreme poverty line) and 6.57 (equivalent to the national poverty line)
		
		Transfer mechanism: quarterly payment NIS 750-1800 with the specific amount determined by the PMTF and hh size.
		Esimated Avg. monthly transfer = NIS 375 to NIS 450
		No. of beneficiaries = 110,272 hh in 2017 (72,166 in Gaza and 38,106 in the West Bank), constituting 687,435 individuals (492,634 in Gaza and 194,801 in the West Bank)
		Mapping:
		Location information and hh size (including by gender) = cover
		Section 5:	Q:1 C01 receiving assistance (clubbed together type of assistance from any party (Cash, food, work, medicine, educational assistance). Recall monthly
					Q:2 C02 amount of assistance (clubbed together). Recall monthly
		Section 6: Q I-101, I-102, I103: hh income code 09 social aid		
					Q I-115: Aid in kind and in cash received from Government and non-government sources (data is both monthly and annually)
2) Martyr's families:
		criteria: shouldn't be receiving cash assistance from Foundation for the Families of Martyrs and Wounded
		Benefit: 157 families received about NIS 1,688,343
		Mapping: identification of Martyr family Section 5: Q C10 "Any family member was exposed  to violence by the occupation( wounded / Martyrs / torture)" but it is clubbed together
		No way to identify if they have been receiving cash assistance from Foundation for the Families of Martyrs and Wounded

3) Discharged Govt. employees:
		Mapping: employment status = tab 1 section 3: L1 status of employment and L6 and L9 for to determine Govt employment

4) Emergency cash assistance for women

*/


*===============================================================================
	* SECTION A: Prepare social protection dataset
*===============================================================================
use "${datapath}/PSE/Monthly_incomeNIS", clear
sort id00 

*A.1 Merge in PECS income section for information on sources of income	
	merge m:1 id00 using "${datapath}/PSE/part6" 
	drop _m

	merge m:1 id00 using "${datapath}/PSE/part5"
	drop _m

* A.2 - Merge in weights
	merge m:1 id00 using "${temppath}hhweight_quantiles" //missing this dataset
	drop _m

	merge 1:1 id00 d1 using "${datapath}/PSE/indvweight" 
	drop _m

* A.3 - Merge in household welfare variables
	rename id00 hhid
	merge m:1 hhid using "${datapath}/PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta" 
	drop _m

save "${temppath}PSE_Social_protection_master.dta", replace
*===============================================================================
    * SECTION B: Create variables and parameters of beneficiaries
*===============================================================================
use "${temppath}PSE_Social_protection_master.dta", clear

* B.1 If hh recieved any type of assistance
	tab c01, m							
	gen rec_assistance = (c01==1)
	tab rec_assistance [fw=int(hhweight)], m	//25.8% yes			

* B.2 Amount of assistance recieved 					
	gen mon_amount_assistance = c02
	gen ann_amount_assistance=(mon_amount_assistance*12)

* ALTERNATE MODULE: B.3 using alternate question in Income module. HH recieved social aid
	tab i01_9, m											// some observations have non-response
	gen rec_social_aid = (i01_9 == 1)						//BA currency of the amount?
	tab rec_social_aid [fw=int(hhweight)], m				//18.55% yes

* For main source of household income
	tab i02 [fw=int(hhweight)], m					//7.26% main source is social aid

* B.4 Monthly income - Government aid cash	        //BA: currency of the amount?
	gen mon_govt_cashaid = i15_5
	gen mon_govt_kindaid = i15_6

	gen ann_govt_cashaid=(mon_govt_cashaid*12)
	gen ann_govt_kindaid=(mon_govt_kindaid*12)

	egen govt_cashaid_total = rowtotal(ann_govt_cashaid), m
	egen govt_kindaid_total = rowtotal(ann_govt_kindaid), m

	qui sum govt_cashaid_total [w=hhweight]
	disp r(sum)/1e6

*===============================================================================
    * SECTION C: Identification of possible beneficiaries of different programs
*===============================================================================
//1. CTP - based on PMTF. Avg monthly transfer NIS 375 to NIS 450

	gen ctp_ben=(inrange (mon_govt_cashaid, 375,450))
	tab ctp_ben [fw=int(hhweight)], m			//1,650 hh
	
	save "${temppath}PSE_SP final.dta", replace

*===============================================================================
	* SECTION D: Social Protection estimation
*===============================================================================
*D1. Save dataset for analysis HH level
*Total nominal consumption
gen gall_n_hh=gall_n*hhsize

collapse (first) region dec qui hhweight popw hhsize gall_n_hh (sum) govt_cashaid_total govt_kindaid_total mon_govt_cashaid ann_govt_cashaid mon_govt_kindaid ann_govt_kindaid ctp_ben, by(hhid)
qui sum govt_cashaid_total [w=hhweight]
disp r(sum)

qui sum govt_kindaid_total [w=hhweight]
disp r(sum)

qui sum popw
disp r(sum)
save "${temppath}PSE_SP results.dta", replace

	
*===============================================================================
	* SECTION E: Preliminary analysis
*===============================================================================	
use   "${temppath}PSE_SP results.dta", clear
collapse (sum) govt_cashaid_total govt_kindaid_total  gall_n_hh [fw=int(hhweight)], by(region dec)
export excel using "$results\PSE_SP results.xls", firstrow(var) sheet(Sheet1, modify) 
	
use   "${temppath}PSE_SP results.dta", clear
collapse (sum) govt_cashaid_total govt_kindaid_total  gall_n_hh [fw=int(hhweight)], by(region qui)
export excel using "$results\PSE_SP results.xls", firstrow(var) sheet(Sheet2, modify) 

use   "${temppath}PSE_SP results.dta", clear
collapse (sum) govt_cashaid_total ctp_ben gall_n_hh [fw=int(hhweight)], by(region qui)
export excel using "$results\PSE_SP results.xls", firstrow(var) sheet(Sheet3, modify) 

		
	
	
	
	
	
	
