* Calculate the Personal Income Tax for Palestine * 
* 2 March 2022 * 
* Maya Goldman * 


loc rerun = 0 

if `rerun'{
	putexcel set "${results}pit_raw.xlsx", sheet("totals") modify
}

*****************************************************************************************************************************
*/1. Combine all the datasets to gather the variables required
*****************************************************************************************************************************

*** 1.1. Weights 
******************************************************************************************************************************

	use "${temppath}hhweight_quantiles.dta", clear 

	drop id02-id09 
	drop qc2-qc5

		qui sum gall [w=hhweight*hhsize] // include East Jersusalem 
		global cons_svy = r(sum)
		disp $cons_svy/1e9

		global cons_adm = 55.087244186*1e9
		disp $cons_adm/1e9		

	tempfile region 
	save `region'

	loc exchangerate = 3.85177
	global cons_admn = 14.302*1e9*`exchangerate'
	if `rerun'{
		putexcel b3 = $cons_admn
		putexcel e3 = $cons_svy
	}
	disp $cons_admn/1e9   //55.08

	loc ratio $cons_svy/$cons_admn   //86.95 
	disp `ratio'



*** 1.4 Individual characteristics
******************************************************************************************************************************

	use "${datapath}/PSE/roster.dta", clear  // Labour force variables
		merge m:1 id00 using `region'
		drop if _merge == 1 
		drop _merge 

		count //20,185


		lab var d1 "Personal ID"
		lab var d3 "Relation"
		lab var d4 "Sex [1=male,0=female]"
		lab var d5_d "Date of birth [day]"
		lab var d5_m "Date of birth [month]"
		lab var d5_y "Date of birth [year]"
		lab var d6 "Age"
		lab var d7 "Refugee status"
		lab var d12_1 "Disability: vision"
		lab var d12_2 "Disability: hearing"
		lab var d12_3 "Disability: movement"
		lab var d12_4 "Disability: focus"
		lab var d12_5 "Disability: communication"
		lab var d18 "Highest level of school"

		g at_school = (d16 == 1)
			lab var at_school "Currently attending school"
		g at_univ = (d18 >= 12 & d18 != 18 & at_school == 1 & inlist(d22,1,3))  //highest level of education completed is greater than grade 12 & indiv. is at school 
			lab var at_univ "Currently attending university"

		g educyr = 0 
		replace educyr = d18 if d18 >= 1 & d18 <= 12
		replace educyr = 14 if d18 == 13 
		replace educyr = 16 if d18 == 14
		replace educyr = 17 if d18 == 15 
		replace educyr = 18 if d18 == 16 
		replace educyr = 19 if d18 == 17

		g female = (d4 == 2)
		g married = (d8 == 1 | d8 == 3)  //what is the "legally married" option about? 
		g refugee = (d7 == 1 | d7 == 2)
		g wbgs = 1 
		replace wbgs = 2 if region == 2 


		bys id00: egen nr_univ_hh = total(at_univ)
			lab var nr_univ_hh "Number of university enrollees (hh)"
		tab nr_univ_hh
		replace nr_univ_hh = 2 if nr_univ_hh > 1

		assert !mi(d5_y)
		assert !mi(d6)  
		ren d6 age  

		g unregistered = (d7 == 2)
			lab var unregistered "Unregistered refugee [1=yes,0=no]"  //assume that unregistered refugees cannot be formal taxpayers 

		tab unregistered [w=int(hhweight)]

		g disability50 = (inlist(d12_1,2,3)|inlist(d12_2,2,3)|inlist(d12_3,2,3)|inlist(d12_4,2,3)|inlist(d12_5,2,3))
			lab var disability50 "50% disability [1=yes,0=no]"
			tab disability50 [w=int(weightt)]  //2.5%



			//MG notes: assume that individuals with a disability that is either great difficulty, or completely can't see, hear, move, focus or communicate is a more than 50% disability as per the tax code 

		g workingage = (age >= 15 & age <= 75) 
			lab var workingage "Working age dummy (15-75) [1=yes, 0=no]"
			tab workingage [w=int(hhweight)]  //65%
				//Legal working age in Palestine is 15. Retirement age is 60. Noone in the dataset above 75 who is working. 

		drop d8-d11
		drop d13-d22

		count //20,185


	tempfile roster
	save `roster'


*** 1.5 Labour force variables 
******************************************************************************************************************************

	use "${datapath}PSE/labor_force.dta", clear  // Labour force variables
		
		drop l2 l3* l4 l11 l12* l13*
		lab var l1 "Relationship to labour force"
		lab var l5 "Labour status"
		lab var l6 "Place of work"
		lab var l7 "Nature of contract"
		lab var l8 "Nature of work"
		lab var l9 "Employer"
		lab var l10 "Working months"
		lab var l14_1 "Pension fund contributions by employer"
		lab var l14_2 "Paid annual leave by employer"
		lab var l14_3 "Paid sick leave by employer"
		lab var l14_4 "Paid maternity leave by employer"
		lab var l14_5 "End of service benefits by employer"



	tempfile labourforce 
	save `labourforce'


*** 1.6 Household income 
******************************************************************************************************************************
	use "${datapath}/PSE/Monthly_incomeNIS.dta", clear  // Labour force variables, 20,149 
		merge m:1 id00 using `region', keepusing(gall region)
		drop if _m == 2
 		drop _m

		lab var i14_1 "Wage: main"
		lab var i14_2 "Wage: seco"
		lab var i14_3 "Wage: in-kind benefits"
		lab var i14_4 "Employer income"
		lab var i14_5 "Self-employed income"
		lab var i14_tot "Total employment income"


		lab var i15_1 "Civilian retirement"
		lab var i15_2 "Military retirement"
		lab var i15_3 "Heritage retirement"

		*codebook i15_1 i15_2 i15_3 
		*hist i15_1 if i15_1 != 0 
		*hist i15_2 if i15_2 != 0 
		*hist i15_3 if i15_3 != 0 
		lab var i15_4 "Private pension funds"
		lab var i15_5 "Governmental aid cash"
		lab var i15_6 "Gov. aid in-kind"
		lab var i15_7 "NGO Aid cash"
		lab var i15_8 "NGO Aid in-kind"
		lab var i15_9 "Green line (land 1948) National insurance"
		lab var i15_10 "Remittances"
		lab var i15_11 "Transfers / gifts from inside"
		lab var i15_tot "Total transfers"

		lab var i16_1 "Gov aid"
		lab var i16_2 "NGO aid"
		lab var i16_3 "Remittances"
		lab var i16_4 "Rental income"
		lab var i16_5 "Land revenue & rent"
		lab var i16_6 "Profit of stocks, bonds, shares"
		lab var i16_7 "Interest from trusts, bonds, investments"
		lab var i16_8 "Other transfers from inside"
		lab var i16_tot "Total"

		g yt_pubp_ri = (i15_1 > 0 | i15_2 > 0 | i15_3 > 0 | i15_4 > 0)  //assume that private pensions are set up by insurance companies and also exempt
		g yt_rent_ri = (i16_4 > 0)

		codebook i15_5 i15_6
		g test = i15_5 + i15_6
		listsome test i16_1 if test != 0 

		codebook i14_1
		egen yt_wage_in_m = rowtotal(i14_1 i14_2 i14_3)
			lab var yt_wage_in_m "Monthly wages for employees"

		g yt_wage_in = yt_wage_in_m*12
			lab var yt_wage_in "Annual wages for employees"
		g yt_self_in = i14_5*12
			lab var yt_self_in "Self-employed income (annual)"
		g yt_empl_in = i14_4*12
			lab var yt_empl_in "Employer income (annual)"
		g yt_rent_in = i16_4*12
			lab var yt_rent_in "Rental income (12m)"
		g yt_land_in = i16_5*12
		g yt_stck_in = i16_6*12*0.75
		g yt_intr_in = i16_7*12
		* egen yt_trns2_in = (i16_1 + i16_2 + i16_3 + i16_8)*12  //This seems to be a duplication of the monthly values. 
		g yt_trns1_in = (i15_5 + i15_6 + i15_7 + i15_8 + i15_9 + i15_10 + i15_11)*12
		assert !mi(yt_trns1_in) // & !mi(yt_trns2_in)

		g yt_retr_in = (i15_1 + i15_2 + i15_3 + i15_4)*12
		
		assert !mi(yt_retr_in)
			lab var yt_retr_in "Annual retirement income"

		loc annual = 1

		// Calculate taxable income 
			egen yt_earn_in = rowtotal(yt_wage_in yt_self_in yt_empl_in)
				lab var yt_earn_in "Taxable earnings (12m): wages + Self-empl. inc."					//At the moment am treating in-kind benefits as taxable income
			egen yt_othr_in = rowtotal(yt_rent_in yt_land_in yt_stck_in yt_intr_in)  	//for the moment am excluding transfers from inside the country. 
				lab var yt_othr_in "Other taxable income (12m)"
			egen yt_ssoc_isrl_in = rowtotal(yt_wage_in yt_self_in yt_empl_in yt_rent_in yt_land_in)

			g pen_publ_in = (i15_1 + i15_2 + i15_3)*12
				lab var pen_publ_in "Retirement income (civilian, military & heritage)"
			g pen_publ_ri = pen_publ_in > 0 
				lab var pen_publ_ri "Retirement income recipient (civilian, military & heritage)"
			assert !mi(pen_publ_in) & !mi(pen_publ_ri)


				listsome yt_earn_in yt_othr_in gall if yt_othr_in > 0 

			*keep id00 d1 yt_earn_in yt_othr_in yt_wage_in 

			//Assuming that given the questionnaire asks about the last section in a 12m timeframe, this has not been converted into a 1 month timeframe. (The results look much more reasonable using this assumption.) 

	tempfile income 
	save `income'



*** 1.7 Consumption
******************************************************************************************************************************

	use "${datapath}/PSE/PSE_Master Consumption.dta", clear
		g cons_trans_hh = mvalue*12 if inrange(item,3501,3502)   
			*assert !mi(cons_trans_hh)
			count if !mi(cons_trans_hh) //8,156 
		g cons_housloanint_hh = mvalue*12 if item == 4302   //with a maximum of 4,000 Shekel annually   
			count if !mi(cons_housloanint_hh)    //127 
		g cons_dons_hh = mvalue*12 if inlist(item,4507,4519,4520)   //4507 = zakhat & charities (in cash); 4519 = charity; 4520 = alms 
			count if !mi(cons_dons_hh)   //374 
		g cons_educ_tert_hh = mvalue if item == 3804
					count if !mi(cons_dons_hh)   //374- education expenditures have a 12 month recall unlike any of the other items in this list
		g cons_taxs_hh = mvalue*12 if item == 4412
			count if !mi(cons_taxs_hh) //1412 
			codebook cons_taxs_hh
		g dtx_taxs_ph = (cons_taxs_hh > 0 & cons_taxs_hh != .)
		g cons_insl_hh = mvalue*12 if item == 4503 
		count if !mi(cons_taxs_hh) //1412 

		collapse (sum) cons_* (max) dtx_taxs_ph, by(id00)
		duplicates list id00

	tempfile consumption
	save `consumption'

	*use "${datapath}PSE_Master Consumption.dta", clear
	*g cons_trans_hh = mvalue*12 if inrange(item,3401,3505)   //no records 

*** 1.8 Dwelling 
******************************************************************************************************************************
	
	use "${datapath}/PSE/dwelling.dta", clear

		lab var h1 "Type of hh unit"
		lab var h3 "Type of occupancy"
		lab var h5 "Main source of funding for acquisition"
		lab var h6 "Source of loan"
		lab var h8 "Payments completed [1=Yes,0=No]"

		g hous = inlist(h1,1,2,3)   //Include only villas and traditional houses
			lab var hous "House type: villa / traditional housing"
		g hous_ownd = (h3 == 1)   
			lab var hous_ownd "House is owned"
		*g purchased = inlist(h4,2,3,4,5)   //personal building or purchased by a broker. Assuming the former means the person built it themselves and gthe latter means they bought it themselves, through a broker. 
		g hous_paym = inlist(h5,1,2,3,4)    //savings, loans, monthly payments to contractor, monthly payments of construction supplies 
			replace hous_paym = 0 if inlist(h5,3,4) & h8 == 1  //if payments are completed assume that tax break not applicable. 
			lab var hous_paym "Ongoing housing payments"

	keep id00 hous hous_ownd hous_paym h5 h6 h8
	
	tempfile housing 
	save `housing'


*** 1.9 Merge datasets together 
******************************************************************************************************************************
	use `region'
		*merge 1:m id00 using `indvweight'   
		*	drop _merge 
		merge 1:m id00 using `roster'   
			drop _merge		
		merge 1:1 id00 d1 using `labourforce'
			drop if _merge == 2
			drop _merge 
		merge 1:1 id00 d1 using `income'
			drop if _merge == 2
			foreach var of varlist yt_*_in{
				replace `var' = 0 if `var'== .
				assert !mi(`var')
			} 
			drop _merge 
					/* It seems normal to have individuals without income reported, so have just replaced any individuals with no income to 0, instead of missing. */

		merge m:1 id00 using `consumption' 
			drop if _merge == 2 
			foreach var of varlist cons_*_hh{
				replace `var' = 0 if `var'== .
				assert !mi(`var')
			} 
			drop _merge  
				/* It seems normal to have individuals without consumption reported for certain items, so have just replaced any individuals with no income to 0, instead of missing. */

		merge m:1 id00 using `housing'
			drop if _merge == 2
			drop _merge 

		qui sum hhweight 
		disp r(sum)  //5.26m 


count // 20,185 - correct. 
count if d1 == 1 // 3,739


*****************************************************************************************************************************
*/2. Simulate formal-workers and taxpayers 
*****************************************************************************************************************************
// Note that I don't currently have a separate method for simulate self-employed formal workers. Need to look at this. 


	g working = (l1 == 1)    // 1.1m individuals 
		lab var working "Currently working [1=Yes,0=No]"
	tab working [w=int(hhweight)]   //29% 
	tab unregistered if working == 1 [w=int(hhweight)]   //29% 
	tab workingage if working == 1 [w=int(hhweight)]   //29% 
	tab disability50 if working == 1 [w=int(hhweight)]   //29% 
		* g employed_2 = (lstatus == 1)   //exactly the same as "working"
		* tab working working_2

	qui sum hhweight if unregistered == 0
	disp r(sum)/1e6
	
	g workertype = .
		lab var workertype "Type of worker"
	replace workertype = 0 if l5 == 3 & working == 1
	replace workertype = 1 if (l5 == 4|l5 == 5) & working == 1
	replace workertype = 2 if (l5 == 2) & working == 1
	replace workertype = 3 if (l5 == 1) & working == 1

	*tab l12 if inlist(workertype, 2,3)
	*tab l13 


	lab def workertype_lbl 0"Unpaid family worker" 1"Employee" 2"Self-employed" 3"Employer"
	lab val workertype workertype_lbl

	tab workertype if working == 1 [w=int(hhweight)]   //2,234 individuals 4.9 m 
			//27 individuals who are unpaid family workers are working and don't have a worker-type 

		assert !mi(workertype) if working == 1

	g pubsector = (inlist(l6,3,4)|inlist(l9,3)) & working == 1 & workingage == 1 
	assert pubsector == 0 if working == 0 | workingage == 0
	g con_pens_pi = 0 
		lab var con_pens_pi "Pension contibutor [1=Yes,0=No]"
	*replace formal = 1 if (unregistered == 0 & workingage == 1 & working == 1 & workertype == 1 & (inlist(l7,1,2) | l14_1 == 1|l14_2==1|l14_4==1) )   //formal employee 
	replace con_pens_pi = 1 if (unregistered == 0 & workingage == 1 & working == 1 & l14_1 == 1)   //formal employee 

	qui sum con_pens_pi [w=int(hhweight)]
	disp r(sum)/1e3 //154.7 thousand
	*replace formal = 1 if pubsector == 1

	
		/* Exclude unregistered refugees, or those not of working age (below 15 or above 75), and include 
			those who  have a contract, or who benefit from employer contributions to a pension fund, annual paid leave, 
				maternity leave */

	*tab formal if working == 1 [w=int(hhweight)]

	* Include all the self-employed and employees (for the moment) 
	*replace formal = 1 if (unregistered == 0 & workingage == 1 & (workertype == 2 |workertype == 3))  
	*tab formal if working == 1 [w=int(hhweight)]
	
	*tabstat formal [w=int(hhweight)], stat(sum) by(workertype)  
	/* 7.1% of individuals are formal or 275 th, compared to about 112.5 taxpayers in the data in 2018. 
									This is according to Table 3c in the background note - number of private taxpayers */

	*tab l6 workertype if formal == 1  [w=int(hhweight)]
	g taxexempt = (inlist(l6,4,7)| inlist(l9,2,5) | disability50 == 1)
		lab var taxexempt "Tax exempt [1=Yes,0=No]"		

	tab taxexempt if working == 1 [w=int(hhweight)]


	qui sum hhweight if con_pens_pi == 1 & taxexempt == 0
	disp r(sum)   //254 th, compared to about 112.5 taxpayers in the data in 2018. 

	tabstat hhweight if con_pens_pi == 1 & taxexempt == 0, by(workertype)

		 
	replace yt_earn_in = 0 if (con_pens_pi == 0 | taxexempt == 1)
	replace yt_othr_in = 0 if (con_pens_pi == 0 | taxexempt == 1)
	egen yt_in = rowtotal(yt_earn_in yt_othr_in)
		lab var yt_in "Taxable income (prior to deductions)"

	g disability_isrl = (l1==12 | d12_1 == 3 | d12_2 == 3 | d12_3 == 3 | d12_4 == 3 | d12_5 == 3)
	g taxexempt_isrl = (inlist(l6,4,7)| inlist(l9,2,5))

	
	lab var pubsector "Public sector worker [1=yes,0=no]"
	g wb = (wbgs == 1)
	lab var wb "West Bank [1=yes,0=no]"



save "${temppath}PSE_pit_prep.dta", replace 

