* Calculate the Personal Income Tax for Palestine * 
* Updated: 30 June 2023 * 
* Maya Goldman * 

/* 
Note that we don't know what order the deductions are applied in, and
 so we apply them in the order of largest to smallest, based on Gabriela Inchauste's advice. 
*/

/* 
/3. Calculate tax exemptions  
	/4. Calculate taxable income after deductions
	/5. Assign individuals to an income-tax bracket 
	/6. Calculate income tax payments

*/


global scale = 1 //if we set this to 1 then scaling is applied to the deductions. 

loc rerun = 0 
if `rerun'{
	putexcel set "${results}pit_raw.xlsx", sheet("totals") modify
}

	use "${temppath}PSE_pit_prep.dta", clear 
	g formal = 0 
	replace formal = 1 if con_pens_pi == 1 & taxexempt == 0

	qui sum formal [w=hhweight]
	disp r(sum)  //114.8

	assert formal == 0 if working == 0
	g formal_plst = (formal == 1 & working == 1 & taxexempt == 0 & inlist(region,1,2) & inlist(l6,1,2,3))
	*replace formal_plst = 0 if region == 2 & pubsector == 0 

	tabstat hhweight if formal_plst == 1, stat(sum) // 111.2 thousand 

	g formal_isrl = (formal == 1 & taxexempt_isrl == 0 & (region == 3 | inlist(l6,5,6)))  //includes those living in EJ or those working in Israel or the settlements
		assert formal_plst == 0 if region == 3 | inlist(l6,5,6) 
		assert formal_isrl == 0 if (region == 1 & l6!= 5 & l6!=6) | (region == 2 & l6!= 5 & l6!=6) | formal == 0 | taxexempt_isrl == 1

	tab formal_isrl [w=int(hhweight)]

*		*listsome region l6 formal taxexempt_isrl disability_isrl if dtx_pitx_isrl_pi == 1 & ((region == 1 & l6!= 5 & l6!=6) | (region == 2 & l6!= 5 & l6!=6) | formal == 0 | taxexempt_isrl == 1)

		lab var formal_plst "Palestinian (formal)"
		lab var formal_isrl "Israeli (formal)"   //lives or works in EJ, or Israel, or settlements
		
		tab formal_plst if working == 1 [w=int(hhweight)]  //4281 th 
		tab formal_isrl if working == 1 [w=int(hhweight)]  //61 th 
		g formal2 = max(formal_plst,formal_isrl)
		assert formal2 != .  
	

tabstat formal_plst [w=hhweight] if formal_plst == 1, by(dec) stat(sum) save
mat define P = [r(Stat1)\r(Stat2)\r(Stat3)\r(Stat4)\r(Stat5)\r(Stat6)\r(Stat7)\r(Stat8)\r(Stat9)\r(Stat10)\r(StatTotal)]

tabstat formal_isrl [w=hhweight] if formal_isrl == 1, by(dec) stat(sum) save
mat define I = [r(Stat1)\r(Stat2)\r(Stat3)\r(Stat4)\r(Stat5)\r(Stat6)\r(Stat7)\r(Stat8)\r(Stat9)\r(Stat10)\r(StatTotal)]

mat define T = [P,I]
mat list T


*****************************************************************************************************************************
*/3. Calculate tax exemptions 
*****************************************************************************************************************************

/* In order to calculate the size of deductions we need to cap it at the size of taxable income. 
	We do this in order of the size of the deductions. 
		We start by setting taxable income after deductions equal to taxable income, and then 
			cumulatively apply the deductions to calculate the new taxable income. 
			*/

	g yt_dedc_in = 0 
	replace yt_dedc_in = yt_in
		lab var yt_dedc_in "Taxable income after deductions"


	g ddc_pitx_plst_pi = (formal_plst == 1 & yt_in > 36000)  //Decree Law No. (5) for the year 2015 on the amendment of the Income Tax Law No. (8) for the year 2011
		lab var formal_plst "Palestinian taxpayer applies for tax deductions (above the genl dedc.)"
		tab formal_plst if working == 1 [w=int(hhweight)]  //281.6 th 

	qui sum hhweight if ddc_pitx_plst_pi == 1
	disp r(sum)   //121 th, compared to about 112.5 taxpayers in the data in 2018. 

	assert inlist(region,1,2)  if ddc_pitx_plst_pi == 1  //151 th


//Calculate individual's share of household taxable income

	bys id00: egen yt_hh = total(yt_in)
		lab var yt_hh "Taxable income (before deductions, hh)"
	g yt_sh = 0
		lab var yt_sh "Share of hh taxable income"
	replace yt_sh = yt_in/yt_hh if formal_plst == 1 | formal_isrl == 1
	replace yt_sh = 0 if yt_sh == . 


*** 3.1. General deduction
******************************************************************************************************************************
		assert yt_in != . 
		g ddc_resd_ri = (yt_in > 0 & formal_plst == 1)
		lab var ddc_resd_ri "Residential deduction recipient"

		g ddc_resd_in = 0 
			lab var ddc_resd_in "Deduction: residential"
		replace ddc_resd_in = min(yt_in,36000) if ddc_resd_ri == 1  
			//there has been some confusion as to whether this is 36 000 or 30 000. Am changing it to 36 000 - anyway it gets scaled down so doesn't matter. 

		qui sum ddc_resd_in [w=hhweight]
		loc resd_svy = r(sum)
		if `rerun'{
			putexcel c5 = `resd_svy'
		}
		disp `resd_svy'/1e6 // 4.9 bil vs. 1.1 bil - 5x too large 


		loc resd_admn = 1101.996*1e6
		loc resd_scalar = (`resd_admn'/$cons_admn)/(`resd_svy'/$cons_svy)
		disp `resd_scalar'

		if $scale == 1{
		replace ddc_resd_in = ddc_resd_in*`resd_scalar'
		}

		qui sum ddc_resd_in [w=hhweight]
		loc resd_svy = r(sum)
		
		if `rerun'{
			putexcel e5 = `resd_svy'
		}
		disp r(sum)/1e6  //863 m

	* Subtract the residential deduction from taxable income
		replace yt_dedc_in = yt_dedc_in - ddc_resd_in if formal_plst == 1
		assert yt_dedc_in <= yt_in & yt_dedc_in != . 
		 


*** 3.3. Donations
******************************************************************************************************************************
	g ddc_dont_in = yt_sh*cons_dons_hh

	qui sum ddc_dont_in [w=hhweight] 
	disp r(sum)/1e6

	replace ddc_dont_in = 0.2*yt_dedc_in if ddc_dont_in > 0.2*yt_dedc_in
	assert ddc_dont_in <= 0.2*yt_dedc_in
	g ddc_dont_ri = (ddc_dont_in > 0 & ddc_pitx_plst_pi == 1)
		
	qui sum ddc_dont_in [w=hhweight] 
	loc dont_svy = r(sum)
	disp `dont_svy'/1e6  //46.36m
	if `rerun'{
			putexcel c10 = `dont_svy'
		}
	replace yt_dedc_in = yt_dedc_in - ddc_dont_in if formal_plst == 1
		assert yt_dedc_in <= yt_in & !mi(yt_dedc_in)


*** 3.3. Deductions for education
******************************************************************************************************************************
* Household pays

		*bys id00: egen formal_hh = max(formal)
		*bys id00: egen formal_hh = min(formal)

		g ddc_univ_rh = (nr_univ_hh > 0 & cons_educ_tert_hh > 0)
		lab var ddc_univ_rh "Deduction recipient: university"
		g ddc_univ_hh = nr_univ_hh*6000*ddc_univ_rh
		lab var ddc_univ_hh "Deductions: university"
		* assert !mi(ddc_univ_hh) FALSE 

		g ddc_univ_ri = (yt_sh > 0 & ddc_univ_rh == 1 & ddc_pitx_plst_pi == 1)
			lab var ddc_univ_ri "Deduction recipient: university"
		g ddc_univ_in = 0 
			lab var ddc_univ_in "Deductions: university"
		replace ddc_univ_in = yt_sh*ddc_univ_hh if ddc_univ_ri == 1 //539 changes
		replace ddc_univ_in = yt_dedc_in if ddc_univ_in > yt_dedc_in
		*replace ddc_univ_in = max(0,yt1_in) if ddc_univ_in > yt1_in
		assert ddc_univ_in >= 0

		qui sum ddc_univ_in [w=hhweight]
		loc educ_svy = r(sum)
		if `rerun'{
			putexcel c6 = `educ_svy'
		}
		disp `educ_svy'/1e6  // 164 mil compared to 6.7 mil - 20 x too large

		*sort id00
		**listsome id00 ddc_univ_rh ddc_univ_hh ddc_univ_in formal taxexempt region yt_in yt_hh yt_sh if id00 == 13

		//Possible that many of these individuals are receiving a scholarship? Can we find out total numbers of scholarships? 
			//Also possible that they don't need to use these deductions because other income is low enough once we take into account contributions and transport.. 


		loc educ_admn = 6.456*1e6
		loc educ_scalar = (`educ_admn'/$cons_admn)/(`educ_svy'/$cons_svy)
		

		if $scale == 1{
			replace ddc_univ_in = ddc_univ_in*`educ_scalar'
		}
			qui sum ddc_univ_in [w=hhweight]
			loc educ_svy = r(sum)
			if `rerun'{
				putexcel e6 = `educ_svy'
			}
			disp `educ_svy'/1e6  // 5.05 mil
		

		replace yt_dedc_in = yt_dedc_in - ddc_univ_in if formal_plst == 1
		assert yt_dedc_in <= yt_in & !mi(yt_dedc_in)




*** 3.4. Housing exemption
******************************************************************************************************************************
	//House purchase / construction = 30 000 NIS one time. Only for house? Or also for apartments?
	* Don't know the year of purchasing or building a house.. but perhaps can just allocate to all individuals who own a house, and scale down? 

	//Gabriela's suggestion is to take out the lumpsum amount and only allocate the interest. 

	g ddc_hous_ownr_ri = (ddc_pitx_plst_pi == 1 & hous == 1 & hous_ownd == 1 & hous_paym == 1)
		lab var ddc_hous_ownr_ri "Deduction recipient: housing purchase / construction"
	g hous_loan = (h5 == 2 & inlist(h6,1,2,4) & h8 == 2)
		lab var hous_loan "House paid for with institutional loan"  //Assuming that loans from family / friends will not qualify for a deduction. Assuming needs to be paperwork. 
	g ddc_hous_loan_ri = (ddc_pitx_plst_pi == 1 & hous == 1 & hous_ownd == 1 & hous_loan == 1)
		lab var ddc_hous_loan_ri "Deduction recipient: housing loan"


	g ddc_hous_ownr_in = (30000*ddc_hous_ownr_ri)/60 //assume a new house is built once in a lifetime of 60 years 

		lab var ddc_hous_ownr_in "Deductions: housing purchase / construction"
	g ddc_hous_loan_in = 4000*ddc_hous_loan_ri
		lab var ddc_hous_loan_in "Deductions: housing loan"

	g ddc_hous_ri = (ddc_hous_ownr_ri == 1 | ddc_hous_loan_ri == 1)
		lab var ddc_hous_ri "Deduction recipient: housing"
	egen ddc_hous_in = rowtotal(ddc_hous_loan_in) // ddc_hous_ownr_in) - remove this from the deductions total 
	*replace ddc_hous_in = ddc_hous_ownr_in*ddc_hous_ownr_ri if (ddc_hous_in == 0 & ddc_hous_ownr_in != 0 )
		lab var ddc_hous_in "Deduction: housing"
		replace ddc_hous_in = yt_dedc_in if ddc_hous_in > yt_dedc_in

	qui sum ddc_hous_in [w=hhweight]
	loc hous_svy = r(sum)
	if `rerun'{
		putexcel c7 = `hous_svy'
	}
	disp `hous_svy'/1e6   //955 m 

	loc hous_admn = 372000 
	loc hous_scalar = (`hous_admn'/$cons_admn)/(`hous_svy'/$cons_svy)

	if $scale == 1{
		replace ddc_hous_in = ddc_hous_in*`hous_scalar'
	}
		qui sum ddc_hous_in [w=hhweight]
		loc hous_svy = r(sum)
		if `rerun'{
			putexcel e7 = `hous_svy'
		}
		disp `hous_svy'/1e6   //291 th 
	

	replace yt_dedc_in = yt_dedc_in - ddc_hous_in if formal_plst == 1
		assert yt_dedc_in <= yt_in & !mi(yt_dedc_in)



*** 3.2. Deductions for fixed transportation  
******************************************************************************************************************************

		//b.	The actual amount paid for fixed transportation to the servants and employees of the public sector. 
		* MG: Does fixed transport mean public transport? Assume that I will include bus and public transport taxi fares only. 

		* Assume that 50% of public transport trips are work-replated for those in the formal sector. 
		/* Note that this doesn't change the final result if we continue to scale it, but it will change the 
		amount that we scale by, so it will make the scaling less dramatic.. */

		global workshare 1 /* Arden chose not to make any assumptions about the share of transport which is spent traveling to work
									and instead to scale down. */

			
		foreach var in trans housloanint dons educ_tert insl{
			g cons_`var'_in = cons_`var'_hh*yt_sh
			assert !mi(cons_`var'_in)
		}
		lab var cons_trans_in "Transport: bus and public taxi"
		lab var cons_housloanint_in "Consumption: housing loan interest"
		lab var cons_dons_in "Consumption: donations"
		lab var cons_educ_tert_in "Consumption: tertiary education"
		lab var cons_insl_in "Consumption: life insurance"

		g ddc_trans_in = 0 
			lab var ddc_trans_in "Deductions: transport"
		replace ddc_trans_in = ${workshare}*cons_trans_in*yt_sh if ddc_pitx_plst_pi == 1
		replace ddc_trans_in = 0.1*yt_earn_in if pubsector == 0 & ddc_trans_in > 0.1*yt_earn_in & ddc_pitx_plst_pi == 1   //116 real changes 
			assert ddc_trans_in == 0 if ddc_pitx_plst_pi == 0 
			assert ddc_trans_in == 0 if cons_trans_in == 0
			compare ddc_trans_in yt_earn_in if pubsector == 0 & ddc_pitx_plst_pi == 1

		qui sum ddc_trans_in [w=hhweight]
		disp r(sum)
		replace ddc_trans_in = yt_dedc_in if ddc_trans_in > yt_dedc_in  


		qui sum ddc_trans_in [w=hhweight]
		loc trans_svy = r(sum)
		if `rerun'{
			putexcel c9 = `trans_svy'
		}
		disp `trans_svy'/1e3   //79.8 mil vs. 0.33 mil 


		qui sum ddc_trans_in if ddc_pitx_plst_pi == 1 [w=hhweight]
		loc trans_svy = r(sum)
		loc trans_admn = 329266  //Note this is 2017 
		loc trans_scalar = (`trans_admn'/$cons_admn)/(`trans_svy'/$cons_svy)
		disp `trans_scalar'

		if $scale == 1{
			replace ddc_trans_in = ddc_trans_in*`trans_scalar'
		}
		qui sum ddc_trans_in [w=hhweight]
		loc trans_svy = r(sum)
		if `rerun'{
			putexcel e9 = `trans_svy'
		}
		disp `trans_svy'/1e3   //268, - looks good 
		

		replace yt_dedc_in = yt_dedc_in - ddc_trans_in if formal_plst == 1
		assert yt_dedc_in <= yt_in & yt_dedc_in != . 


*** 3.5. Contributions to savings or other funds exemption (this should probably be moved up front and subtracted immediately from taxable income... )
******************************************************************************************************************************

/* Benefits under the scheme include a welfare component, a defined benefit (DB) component, and a defined contribution (DC) component.
Contributions: For the DB component, employers contribute 9% while employees contribute 7% “of paid up salary.”  
For the DC component, employer and employee each contribute 3%. */
	
	g net = . 
	replace net = 1 if (workertype == 1 & formal == 1 & yt_wage_in > 0)
	replace net = 0 if (inlist(workertype,2,3) & formal == 1 & yt_wage_in > 0)

* Palestine: pension contributions and deductions 
**********************************************************************
	g con_pens_plst_pi = (con_pens_pi & inlist(region,1,2))   //l14_1 == 1
	tab con_pens_plst_pi [w=int(hhweight)]  //149.8 th 
	lab var con_pens_plst_pi "Pension contributor (Palestine)"
	count if con_pens_plst_pi == 1 & age >= 55

	qui sum con_pens_plst_pi [w=hhweight]
	disp r(sum)/1e3

	g under55 = (age < 55) 

	qui sum if con_pens_plst_pi == 1 & under55 == 1 [w=hhweight]
	disp r(sum)/1e3
	qui sum if con_pens_plst_pi == 1 [w=hhweight]
	disp r(sum)/1e3
	qui sum if con_pens_plst_pi == 1 & under55 == 0 & region == 2 [w=hhweight]
	disp r(sum)
	qui sum if con_pens_plst_pi == 1 & under55 == 0 & region == 1 [w=hhweight]
	disp r(sum)

	g con_pens_wrkr_plst_in = 0 
	replace con_pens_wrkr_plst_in = (0.07*yt_wage_in + 700)*con_pens_plst_pi*under55    //Sch II:  
		lab var con_pens_wrkr_plst_in "Worker pension contributions (Palestine)"
		replace con_pens_wrkr_plst_in = 0.1*yt_wage_in*con_pens_plst_pi if under55 == 0 & region == 2 & (pubsector == 1|l9 == 3)  //Sch I: Gaza - According to PER on pensions, only 10% of this scheme was received 
		replace con_pens_wrkr_plst_in = 0.02*yt_wage_in*con_pens_plst_pi if under55 == 0 & region == 1 & pubsector == 1 //Sch IV: West Bank - nothing received for this scheme so set to 0 
	g con_pens_empl_plst_in = 0
		replace con_pens_empl_plst_in = 0.09*yt_wage_in*con_pens_plst_pi*under55   //Sch II: 
		lab var con_pens_empl_plst_in "Employer pension contributions (Palestine)"
		replace con_pens_empl_plst_in = 0.125*yt_wage_in*con_pens_plst_pi if under55 == 0 & region == 2 & (pubsector == 1|l9 == 3) //Sch I:  Gaza -  //According to PER on pensions, only 10% of this scheme was received 
		*replace con_pens_empl_plst_in = 0*yt_wage_in*con_pens_plst_pi if under55 == 0 & region == 1 & pubsector == 1 //Sch IV: No employer contributions for West Bank 

		//Note that Scheme III is only for security services, which can't be identified, and so is not applied. 



	qui sum con_pens_wrkr_plst_in if con_pens_plst_pi == 1 [w=hhweight]
		disp r(sum)/1e6   //481 mil 

		qui sum con_pens_empl_plst_in if con_pens_plst_pi == 1 [w=hhweight]
		disp r(sum)/1e6   //479 

		qui sum yt_wage_in [w=hhweight] if con_pens_plst_pi == 1
		disp r(sum)/1e6  //8908 

		disp (413+479)/8908  //10%  - this doesn't sound too bad.. 



/****** Add in the scaling : 

		loc con_pens_2013 = 70.8*1e6 //Pensions PER (including the retiree portion only, not disability or survivorship)

		* ceqppp, c("PSE") b(2011) s(2013)  - 2016 = 110.74693 \ 2013 = 107.55961
		loc con_pens_2016 = 110.74693/107.55961*`con_pens_2013'
		disp `con_pens_2016'/1e6  //99 m 

		loc effrate_na = `con_pens_2016'/$cons_admn
		disp `effrate_na'*100  //0.18 

		qui sum con_pens_wrkr_plst_in [w=hhweight] if con_pens_plst_pi == 1
		loc con_pens_wrkr_plst = r(sum)
		qui sum con_pens_empl_plst_in [w=hhweight] if con_pens_plst_pi == 1
		loc con_pens_empl_plst = r(sum)
		loc con_pens_plst = `con_pens_wrkr_plst'+`con_pens_empl_plst'
		disp `con_pens_plst'/1e6 

		loc effrate_svy = `con_pens_plst'/$cons_svy
		disp `effrate_svy'

		loc scalar = `effrate_na'/`effrate_svy'

		replace con_pens_wrkr_plst_in = `scalar'*con_pens_wrkr_plst_in
		replace con_pens_empl_plst_in = `scalar'*con_pens_empl_plst_in
*/
		qui sum con_pens_wrkr_plst_in [w=hhweight]
		loc penswrkr = r(sum)
		disp `penswrkr'

		qui sum con_pens_empl_plst_in [w=hhweight]
		loc pensempl = r(sum)
		disp (`penswrkr' + `pensempl')/1e6  //614.6 


	egen ddc_cont_in = rowtotal(con_pens_wrkr_plst_in) //employer's contribution is a tax deductible from the business but but not an exemption for individuals 
	replace ddc_cont_in = 0 if formal_plst == 0 //those who are tax exempt will not have pension deductions
		*replace ddc_cont_in = 0 if ddc_pitx_plst_pi == 0
		lab var ddc_cont_in "Deduction: contributions to savings"   
		replace ddc_cont_in = yt_dedc_in if ddc_cont_in > yt_dedc_in    
		assert ddc_cont_in == 0 if formal_plst == 0 

	qui sum ddc_cont_in [w=hhweight]
	loc cont_svy = r(sum)
	disp `cont_svy'/1e3   //284.1 mil 
	if `rerun'{
		putexcel c8 = `cont_svy'
	}
	
 
	loc cont_admn = 34151
	loc penscont_scalar = (`cont_admn'/$cons_admn)/(`cont_svy'/$cons_svy)

	if $scale == 1{
		replace ddc_cont_in = ddc_cont_in*`penscont_scalar'
	}
	
	qui sum ddc_cont_in [w=hhweight]
	loc cont_svy = r(sum)
	disp `cont_svy'/1e3   //30 th
	
	if `rerun'{
		putexcel e8 = `cont_svy'
	}

	replace yt_dedc_in = yt_dedc_in - ddc_cont_in if formal_plst == 1 & net == 0 //only subtract off if income is gross, otherwise it is already subtracted.  
		assert yt_dedc_in <= yt_in & !mi(yt_dedc_in)
	
	
// Assuming that reported salaries and wages is gross of contributions... 

***********************************************************************
* Israel 
***********************************************************************

*** 3.8. Disability 
***********************************************************************

ren disability_isrl ddc_disb_isrl_ri 
g ddc_disb_isrl_in = 606000*ddc_disb_isrl_ri
replace ddc_disb_isrl_in = yt_in if ddc_disb_isrl_in > yt_in & formal_isrl == 1 // 0 
replace yt_dedc_in = yt_in - ddc_disb_isrl_in if formal_isrl == 1   
assert yt_dedc_in != . & yt_dedc_in <= yt_in


* Pension and NHI contributions and deductions
**********************************************************************

	//Note that I assume that only salaried workers are making mandatory pension contributions, but that all Israeli workers are majing mandatory NHI contributions
		// According to the National Health Insurance Law, as of January 1st 1995, all Israeli residents are required to be covered by medical insurance. 
			//Therefore, each resident is required to be an insured member of one of the health funds.

	* National Insurance = basic contributions + health levy
	* Health levy: Payment is 3.1% up to 60% of the average wage - struggling to find the average wage amount for 2016. Doesn't seem to relate to the average wage according to the CBS. 

	/* It seems as if contributions are tax deductible ONLY for self-employed workers or non-working individiduals. Because only Israeli workers are included here 
		we can focus on the former.*/

********* NATIONAL INSURANCE ***********

/* The current monthly National Insurance (Bituach Leumi) rates for Israeli residents, including the health levy, and national insurance (social security), 
	which is also payable at various rates on most types of income up to NIS 43,240 a month (in 2016), are as follows:
	* Resident employees: 3.5%-12%
	* Employers of resident employees: 3.45%-7.5%.
	* Nonresident employees: 0.04%- 0.87%
	* Employers of nonresident employees: 0.49%-2.55%
	* Self-employed individuals: 9.82%- 16.23% (52% of the NII amount paid is tax deductible)
	* Not working: 9.61%-12% (52% of the NII amount paid is tax deductible)
	* Payment if no income: NIS 168 per month.
	No National Insurance liability applies to monthly income exceeding NIS 43,240. There is also no National Insurance liability regarding dividends and capital gains. But the profits of fiscally transparent ‘‘family companies‘‘ are assessable to national insurance.
	Other rates apply to early retirees, domestic helpers and certain others.
*/

	loc avgwage_60p = 0.6*5678.4*12  //60% of the average wage for 2016 (https://www.btl.gov.il/English%20Homepage/Mediniyut/GeneralInformation/Pages/AverageWage.aspx)
	loc maxpay_lowrate = 0.031*`avgwage_60p' 
	disp `min'  //2211.168

	loc maxwage = 43240*12  
	/* This seems to be the amount for both 2016 & 2017 amount - https://h2cat.com/your-taxes-israeli-tax-rates-in-2016/ & https://h2cat.com/your-taxes-israeli-tax-rates-in-2017/. 
		Confirmed in https://www.btl.gov.il/Publications/Habituah_haleumi/Documents/charth16-e.pdf */

	loc maxpay (`maxwage'-`avgwage_60p')*0.05 + `maxpay_lowrate' //25130.861
	disp `maxpay'


	g con_ssoc_isrl_pi = (formal_isrl == 1)
	assert con_ssoc_isrl_pi == 1 if l14_1 == 1 & inlist(l6,5,6) & formal_isrl == 1 & taxexempt_isrl == 0
	tab workertype if con_ssoc_isrl_pi
		lab var con_ssoc_isrl_pi "Contributor to NHI"
		assert !mi(yt_ssoc_isrl_in)
/* 
	g nhi = 0
	replace nhi = 1 if age >= 18 & con_ssoc_isrl_pi == 1 & yt_ssoc_isrl_in == 0 
	replace nhi = 2 if age >= 18 & con_ssoc_isrl_pi == 1 & yt_ssoc_isrl_in > 0 & yt_ssoc_isrl_in <= `avgwage_60p'
	replace nhi = 3 if age >= 18 & con_ssoc_isrl_pi == 1 & yt_ssoc_isrl_in > `avgwage_60p'
	replace nhi = 4 if age >= 18 & con_ssoc_isrl_pi == 1 & yt_ssoc_isrl_in > `maxwage' 
*/
	//NHI contribution = 0.12 and 52% is tax deductible 
	g ddc_nhi_in = 0 
	replace ddc_nhi_in = 0.12*0.52*yt_dedc_in if formal_isrl == 1 & workertype == 2 & yt_in <= `maxwage'  //40 changes 
	replace ddc_nhi_in = 0.12*0.52*`maxwage' if formal_isrl == 1 & workertype == 2 & yt_in > `maxwage'  //0 changes 
		// Note that pension contributions are deducted as a credit after tax liability is calculated 
		replace ddc_nhi_in = yt_dedc_in if ddc_nhi_in > yt_dedc_in & formal_isrl == 1 // 0 
		replace yt_dedc_in = yt_dedc_in - ddc_nhi_in if formal_isrl == 1 & net == 0 
		replace yt_dedc_in = yt_dedc_in + ddc_nhi_in*(48/52) if formal_isrl == 1 & net == 1   
			/* a salary net of deductions will presumably be reported net of the whole NHI amount, and for the sake of taxable income, 
				we only want to subtract the deductible part, so we need to add 48% back in. */
		assert yt_dedc_in != . & yt_dedc_in <= yt_in 


*** 3.7. Israel: rental 
******************************************************************************************************************************
//Two options for taxing rental income. Either a deduction and then the remainder is taxed at the marginal rate OR 10% tax on rental income (under special conditions). 
	//We assume the first option. 

	count if yt_pubp_ri == 1 & yt_rent_ri == 1 & formal_isrl == 1 // no individuals are receiving rent and pensions simultanously in Israel 
	assert yt_rent_in > 0 if yt_rent_ri == 1


	* Israeli exemptions for first 5010 NIS per month of rental income (https://h2cat.com/your-taxes-israeli-tax-rates-in-2017/)
		g ddc_rent_isrl_ri = (yt_rent_ri == 1 & formal_isrl == 1)
		g ddc_rent_isrl_in = 0
		replace ddc_rent_isrl_in = min(yt_rent_in,60120) if formal_isrl == 1  //9 replacements
		replace ddc_rent_isrl_in = yt_dedc_in if ddc_rent_isrl_in > yt_dedc_in & formal_isrl == 1 // 0 
		replace yt_dedc_in = yt_dedc_in - ddc_rent_isrl_in if formal_isrl == 1  //13 
		assert yt_dedc_in != . & yt_dedc_in <= yt_in 


* Size of scalars 

disp `resd_scalar'  //0.15 
disp `trans_scalar' //0.0038
disp `hous_scalar' //0.0062
disp `educ_scalar' //0.27 
disp `penscont_scalar' //0.00014


* Pension contributions: subtracted in 11.4 as a credit 

********** Pension contributions: Israel *************

	g con_pens_isrl_pi = (con_pens_pi == 1 & workertype == 1 & (region == 3 | inlist(l6,5,6)))
	qui sum con_pens_isrl_pi [w=hhweight]
	disp r(sum)/1e3
	lab var con_pens_isrl_pi "Contributor to pensions (Israel)"
	assert con_pens_isrl_pi == 0 if formal_plst == 1 

	g con_pens_wrkr_isrl_in = 0 
		replace con_pens_wrkr_isrl_in = 0.055*yt_in*con_pens_isrl_pi   //From 2014-2017 employee contributions were 5.5% - OECD  
		lab var con_pens_wrkr_isrl_in "a. Worker pension contributions (Israel)"

		assert !mi(con_pens_isrl_pi) & !mi(con_pens_wrkr_isrl_in)
		replace con_pens_isrl_pi = 0 if con_pens_wrkr_isrl_in == 0 

	g con_pens_empl_isrl_in = 0 
		replace con_pens_empl_isrl_in = 0.12*yt_in*con_pens_isrl_pi    
		lab var con_pens_empl_isrl_in "b. Employer pension contributions (Israel)"


*****************************************************************************************************************************
*/4. Calculate taxable income after deductions
*****************************************************************************************************************************
*****************************************************************************************************************************

sum ddc_resd_in if ddc_resd_ri == 1  //26 thou 
sum ddc_trans_in if ddc_trans_in > 0 //5 631 
sum ddc_cont_in if con_pens_plst_pi == 1 //2 448
sum ddc_dont_in if ddc_dont_ri == 1 // 1 483
sum ddc_hous_in if ddc_hous_ri == 1 //237 
sum ddc_univ_in if ddc_univ_ri == 1 // 190 
 


* Palestine 
	assert !mi(ddc_univ_in) & !mi(ddc_trans_in) & !mi(ddc_cont_in) & !mi(ddc_resd_in) & !mi(ddc_hous_in) & !mi(ddc_dont_in) 
	egen ddc_plst_in = rowtotal(ddc_univ_in ddc_trans_in ddc_cont_in ddc_resd_in ddc_hous_in ddc_dont_in) if formal_plst == 1

* Israel 
	assert !mi(ddc_rent_isrl_in) & !mi(ddc_cont_in) if formal_isrl == 1
	egen ddc_isrl_in = rowtotal(ddc_cont_in ddc_rent_isrl_in ddc_disb_isrl_in) if formal_plst == 1

* Total 
	egen ddc_in = rowtotal(ddc_plst_in ddc_isrl_in)
	
*drop if yt_dedc_in > 800000   //why am I doing this?!! 



******************************************************************************************************************************
*/5. Assign individuals to an income-tax bracket 
******************************************************************************************************************************
*****************************************************************************************************************************



if `rerun'{
	putexcel set "${results}pit_raw.xlsx", sheet("Taxpyer nrs") modify
}


* Palestine

// Note that Palestinian income tax brackets do not seem to have been updated since 2011! 
	// https://taxsummaries.pwc.com/palestinian-territories/individual/taxes-on-personal-income

* Calculate bracket threshold for net and gross 
	* Palestine 
	
		//Employee contributions are 0.07 + 0.03 in Palestine 

		g thresh_plst_1 = 75000 if net == 0 
		replace thresh_plst_1 = 75000-3750 if net == 1
		g thresh_plst_2 = 150000 if net == 0
		replace thresh_plst_2 = 150000-11250 if net == 1

		*listsome yt_dedc_in net thresh_plst_1 thresh_plst_2 if net != . 

	g pitbracket_plst = . 
		lab var pitbracket_plst "Maximum income bracket"
	*replace pitbracket_plst = 0 if yt_dedc_in == (0) & formal_plst == 1
	replace pitbracket_plst = 1 if yt_dedc_in > 0 & yt_dedc_in <= (thresh_plst_1) & formal_plst == 1 
	replace pitbracket_plst = 2 if yt_dedc_in > (thresh_plst_1) & yt_dedc_in <= (thresh_plst_2) & formal_plst == 1 
	replace pitbracket_plst = 3 if yt_dedc_in > (thresh_plst_2) & formal_plst == 1 

	*listsome pitbracket_plst yt_dedc_in if formal_plst == 1

	assert pitbracket_plst == . if formal_plst == 0 
	assert pitbracket_plst == 1 if yt_dedc_in > 0 & yt_dedc_in <= thresh_plst_1 & formal_plst == 1
	assert pitbracket_plst == 2 if yt_dedc_in > thresh_plst_1 & yt_dedc_in <= thresh_plst_2 & formal_plst == 1
	assert pitbracket_plst == 3 if yt_dedc_in > thresh_plst_2 & formal_plst == 1

	lab def pitbracket_plst_lbl 1"<= 75 th" 2"<= 150 th" 3">= 150 th"
	lab val pitbracket_plst pitbracket_plst_lbl


	tabstat hhweight, stat(sum)

* Israel
* Source of tax rates 2016-17: https://www.aaptaxlaw.com/World-Taxes/Israel-Income-Tax-Rates-2014-Corporation-Tax-Rate-in-Israel-VAT-Tax-TDS.html
	* Max thresdhold: 0.12*518880  


//NHI contribution = 0.12 and pension contribition = 0.05 - SUM = 0.175

	g thresh_isrl_1 = 62640 if net == 0
		replace thresh_isrl_1 = (62640*(1-0.055)-6264) if net == 1
	g thresh_isrl_2 = 107040 if net == 0
		replace thresh_isrl_2 = (107040*(1-0.055)- 12480) if net == 1
	g thresh_isrl_3 = 166320 if net == 0
		replace thresh_isrl_3 = (166320*(1-0.055)- 24928.8) if net == 1
	g thresh_isrl_4 = 237600 if net == 0
		replace thresh_isrl_4 = (237600*(1-0.055)- 47025.6) if net == 1
	g thresh_isrl_5 = 496920 if net == 0
		replace thresh_isrl_5 = (496920*(1-0.055)- 135194.4) if net == 1
	g thresh_isrl_6 = 803520 if net == 0
		replace thresh_isrl_6 = (803520*(1-0.055)- 282362.4) if net == 1

	*listsome thresh_isrl_* if net != . 

	g pitbracket_isrl = . 
		lab var pitbracket_isrl "Maximum income bracket"
	replace pitbracket_isrl = 1 if yt_dedc_in > 0 & yt_dedc_in <= thresh_isrl_1 				& formal_isrl == 1 
	replace pitbracket_isrl = 2 if yt_dedc_in > thresh_isrl_1 & yt_dedc_in <= thresh_isrl_2 	& formal_isrl == 1 
	replace pitbracket_isrl = 3 if yt_dedc_in > thresh_isrl_2 & yt_dedc_in <= thresh_isrl_3 	& formal_isrl == 1 
	replace pitbracket_isrl = 4 if yt_dedc_in > thresh_isrl_3 & yt_dedc_in <= thresh_isrl_4 	& formal_isrl == 1 
	replace pitbracket_isrl = 5 if yt_dedc_in > thresh_isrl_4 & yt_dedc_in <= thresh_isrl_5 	& formal_isrl == 1 
	replace pitbracket_isrl = 6 if yt_dedc_in > thresh_isrl_5 & yt_dedc_in <= thresh_isrl_6 	& formal_isrl == 1 
	replace pitbracket_isrl = 7 if yt_dedc_in > thresh_isrl_6 									& formal_isrl == 1

	lab def pitbracket_isrl_lbl 1"<63th" 2" 63-107th" 3"107-166th" 4"166-238th" 5"238-497th" 6"497-804th" 7">804th"


tab pitbracket_plst pitbracket_isrl, missing


******************************************************************************************************************************
*/6. Calculate income tax payments 
******************************************************************************************************************************
*****************************************************************************************************************************



	if `rerun'{
		putexcel set "${results}pit_raw.xlsx", sheet("totals") modify
	}

	disp 0.05*75000
	disp 0.05*75000 + 0.1*(150000-75000)

* Palestine

/* Formula: (G-T_i) * t_i + L_i = x 					... 1. 
			N = G-x-C 									... 2. 
			G= (N + x + C) 								... 3.
			(N + x + C -T_i) * t_i + L_i = x 			... 4.
			(N + C - T_i) * t_i + L_i = x - x*t-i		... 5.
			(N + C -T_i) * t_i + L_i = x*(1 - t-i)		... 6.
			x = [(N + C -T_i) * t_i + L_i]/(1 - t-i)	... 7.
			
			N + C = yt_dedc_in + con_pens_wrkr_plst_in

	* where G is Gross income, T_i is the threshold, t_i is the tax rate and L_i is the lump sum maximum tax at the bracket floor, 
		c is the share of gross contributions, N is net income, and x is the tax liability */

* Therefore: 


/* Note that if: 
1. income is assumed to be gross: then we have already subtracted pension contributions - they are tax deductible. 
2. income is assumed to be net: then we have not subtracted pension contributions, because they are already subtracted. 

Either way - no need to remove pension contributions or add them back in prior to income tax calculation */


* Scale down the number of Palestinian taxpayers 
**************************************************************************
/* Include only those that pay pension contributions as taxpayers, to 
reduce the number of eligible people to about the right number of taxpayers */

replace formal_plst = 0 if con_pens_plst_pi == 0

**************************************************************************

	g dtx_pitx_plst_in = 0 
		lab var dtx_pitx_plst_in "Palestinian Income tax"
	replace dtx_pitx_plst_in = 0.05*yt_dedc_in 									if pitbracket_plst == 1 & formal_plst == 1 & net == 0
	replace dtx_pitx_plst_in = 0.05*(yt_dedc_in + con_pens_wrkr_plst_in)/(1 - 0.05) 							if pitbracket_plst == 1 & formal_plst == 1 & net == 1
	replace dtx_pitx_plst_in = 0.1*(yt_dedc_in - 75000) + 3750 						if pitbracket_plst == 2 & formal_plst == 1 & net == 0
	replace dtx_pitx_plst_in = (0.1*(yt_dedc_in + con_pens_wrkr_plst_in - 75000) + 3750)/(1-0.1)				if pitbracket_plst == 2 & formal_plst == 1 & net == 1
	replace dtx_pitx_plst_in = 0.15*(yt_dedc_in - 150000) + 11250  					if pitbracket_plst == 3 & formal_plst == 1 & net == 0
	replace dtx_pitx_plst_in = (0.15*(yt_dedc_in + con_pens_wrkr_plst_in - 150000) + 11250)/(1-0.15) 			if pitbracket_plst == 3 & formal_plst == 1 & net == 1

	*listsome dtx_pitx_plst_in yt_dedc_in pitbracket_plst if formal_plst == 1 & net == 1


/* Gross income up by the amount of income tax calculated, and then by the worker pension contributions to check the income tax calculation */
	g yt_gross_in = yt_dedc_in 
	replace yt_gross_in = yt_dedc_in if net == 0 & formal_plst == 1
	replace yt_gross_in = (yt_dedc_in + con_pens_wrkr_plst_in + dtx_pitx_plst_in) if net == 1 & formal_plst == 1


	g  dtx_pitx_plst_pi = (dtx_pitx_plst_in > 0) 

	qui sum dtx_pitx_plst_pi if con_pens_plst_pi == 1 [w=hhweight]
	disp r(sum)/1e3


	assert formal == 1 if formal_plst == 1
	g check = 0.05*(yt_gross_in*(1-0.1)-700) if pitbracket_plst == 1 & formal_plst == 1 & net == 1
	replace check = 3750 + 0.1*(yt_gross_in*(1-0.1)-700-75000) if pitbracket_plst == 2 & formal_plst == 1 & net == 1
	replace check = 11250 + 0.15*(yt_gross_in*(1-0.1)-700-150000) if pitbracket_plst == 3 & formal_plst == 1 & net == 1

	*assert check <= 1.1*dtx_pitx_plst_in & check >= 0.99*dtx_pitx_plst_in if net == 1 & formal_plst == 1

	assert dtx_pitx_plst_in == 0 if dtx_pitx_plst_pi == 0 

	assert 3750 == 0.05*75000
	assert 11250 == 3750 + 0.1*(150000-75000)


************************************************************************************************************

* Israel


***** National insurance contributions are removed only for self-employed workers, which are all assumed to report gross income, so this is already deducted. 
* For other workers,  

g dtx_pitx_isrl_empl_in = 0 
	lab var dtx_pitx_isrl_empl_in "Israeli Income tax pre-credit"
	replace dtx_pitx_isrl_empl_in = 0.1*yt_dedc_in 					 	if pitbracket_isrl == 1 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 6264 + 0.14*(yt_dedc_in-62640) 	 	if pitbracket_isrl == 2 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 12480 + 0.21*(yt_dedc_in-107040) 	if pitbracket_isrl == 3 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 24928.8 + 0.31*(yt_dedc_in-166320) 	if pitbracket_isrl == 4 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 47025.6 + 0.34*(yt_dedc_in-237600) 	if pitbracket_isrl == 5 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 135194.4 + 0.48*(yt_dedc_in-496920) if pitbracket_isrl == 6 & formal_isrl == 1 & net == 0
	replace dtx_pitx_isrl_empl_in = 282362.4 + 0.50*(yt_dedc_in-803520) if pitbracket_isrl == 7 & formal_isrl == 1 & net == 0

	* Net contributions are calculated by first grossing up for employer contributions to pensions 
	disp 1-0.055
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945)*0.1)/(1-0.1/0.945)					if pitbracket_isrl == 1 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-62640)*0.14 + 6264)/(1-0.14/0.945)	 		if pitbracket_isrl == 2 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-107040)*0.21 + 12480)/(1-0.21/0.945) 		if pitbracket_isrl == 3 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-166320)*0.31 + 24928.8)/(1-0.31/0.945) 		if pitbracket_isrl == 4 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-237600)*0.34 + 47025.6)/(1-0.34/0.945) 		if pitbracket_isrl == 5 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-496920)*0.48 + 135194.4)/(1-0.48/0.945) 		if pitbracket_isrl == 6 & formal_isrl == 1 & net == 1
	replace dtx_pitx_isrl_empl_in = ((yt_dedc_in/0.945-803520)*0.50 + 282362.4)/(1-0.50/0.945) 		if pitbracket_isrl == 7 & formal_isrl == 1 & net == 1 

	*listsome yt_dedc_in dtx_pitx_isrl_empl_in pitbracket_isrl if formal_isrl == 1 & net == 1

	replace yt_gross_in = (yt_dedc_in*(1+0.055) + dtx_pitx_isrl_empl_in)/(1-0.055) if net == 1 & formal_isrl == 1

	replace check = 0.1*yt_gross_in 					 	if pitbracket_isrl == 1 & formal_isrl == 1 & net == 1
	replace check = 6264 + 0.14*(yt_gross_in-62640) 	 	if pitbracket_isrl == 2 & formal_isrl == 1 & net == 1
	replace check = 12480 + 0.21*(yt_gross_in-107040) 		if pitbracket_isrl == 3 & formal_isrl == 1 & net == 1
	replace check = 24928.8 + 0.31*(yt_gross_in-166320) 	if pitbracket_isrl == 4 & formal_isrl == 1 & net == 1
	replace check = 47025.6 + 0.34*(yt_gross_in-237600) 	if pitbracket_isrl == 5 & formal_isrl == 1 & net == 1
	replace check = 135194.4 + 0.48*(yt_gross_in-496920) 	if pitbracket_isrl == 6 & formal_isrl == 1 & net == 1
	replace check = 282362.4 + 0.50*(yt_gross_in-803520) 	if pitbracket_isrl == 7 & formal_isrl == 1 & net == 1

	assert (check <= 1.1*dtx_pitx_isrl_empl_in) | (check >= 0.99*dtx_pitx_isrl_empl_in) if net == 1 & formal_isrl == 1
	**listsome yt_gross_in yt_dedc_in thresh_isrl_6  check dtx_pitx_isrl_empl_in pitbracket_isrl if  net == 1 & formal_isrl == 1 & target == 1
	assert dtx_pitx_plst_in >= 0 
	g  dtx_pitx_isrl_pi = (dtx_pitx_isrl_empl_in > 0)
	assert dtx_pitx_isrl_empl_in >= 0 

	cap drop check


save "${temppath}temp_pit.dta", replace

qui sum dtx_pitx_plst_in [w=hhweight]
disp r(sum)/1e6  //364.9

qui sum dtx_pitx_isrl_empl_in [w=hhweight]
disp r(sum)/1e6  //379.8 

qui sum dtx_pitx_plst_pi [w=hhweight]
disp r(sum)/1e3  //186.9 - looks good! 

qui sum dtx_pitx_isrl_pi [w=hhweight]
disp r(sum)/1e3  //46.9 - don't have numbers to compare with..  


************************************************************************************
* Income Tax - before medical credits (do-file 11.4)
************************************************************************************








