* Calculate the Pension contributions for Palestine and subtract the tax credits from the income tax calculaiton* 
* 25 May 2022 * 
* Maya Goldman * 

loc rerun = 0 

use "${temppath}temp_pit.dta", replace

* Calculate the share of workers that are formal, by decile, for the report: 
preserve
	collapse (sum) working formal [w=hhweight], by(dec)
	g share = round((formal/working)*100,.1)
	export excel using "${results}Formal.xlsx", firstrow(var) sheet("Sheet1", modify)
restore


	g dtx_pitx_isrl_pass_in = 0
	lab var  dtx_pitx_isrl_pass_in "Tax on passive income (25% minimum rate)"
	replace dtx_pitx_isrl_pass_in = 0.25*(yt_stck_in + yt_intr_in) if dtx_pitx_isrl_pi == 1

		//Source: https://taxsummaries.pwc.com/israel/individual/income-determination and https://h2cat.com/your-taxes-israeli-tax-rates-in-2017/

********** Pension contributions:  *************
//Recalculate the pension contributions now using gross income. 

* Workers
		replace con_pens_wrkr_plst_in = (0.07*yt_gross_in + 700)*con_pens_plst_pi*under55
		*lab var con_pens_wrkr_plst_in "Worker pension contributions (Palestine)"
		replace con_pens_wrkr_plst_in = 0.1*yt_gross_in*con_pens_plst_pi if under55 == 0 & region == 2 & (pubsector == 1|l9 == 3) // Gaza
		replace con_pens_wrkr_plst_in = 0.02*yt_gross_in*con_pens_plst_pi if under55 == 0 & region == 1 & pubsector == 1  // West Bank 
	
	* Total 
		egen con_pens_plst_in = rowtotal(con_pens_wrkr_plst_in con_pens_empl_plst_in)
		lab var con_pens_plst_in "Pension contributions (Palestine)"
		replace con_pens_plst_pi = 0 if con_pens_plst_in == 0  //12 changes 

		qui sum con_pens_plst_in [w=hhweight] 
		disp r(sum)/1e6  //748.3 


********** Pension contributions: Israel *************
	
		replace con_pens_wrkr_isrl_in = 0.055*yt_gross_in*con_pens_isrl_pi   //From 2014-2017 employee contributions were 5.5% - OECD  
		assert !mi(con_pens_isrl_pi) & !mi(con_pens_wrkr_isrl_in)
		replace con_pens_isrl_pi = 0 if con_pens_wrkr_isrl_in == 0 
		replace con_pens_empl_isrl_in = 0.12*yt_gross_in*con_pens_isrl_pi    
	

	
	egen con_pens_isrl_in = rowtotal(con_pens_wrkr_isrl_in con_pens_empl_isrl_in)
	egen con_pens_in = rowtotal(con_pens_plst_in con_pens_isrl_in)

	qui sum con_pens_plst_in [w=hhweight]
	disp r(sum)/1e6  //67.9 
	qui sum con_pens_isrl_in [w=hhweight]
	disp r(sum)/1e6  //36.5 
	
	qui sum con_pens_in [w=hhweight]
	disp r(sum)/1e6  //104.5 

	*g con_pens_pi = (con_pens_isrl_pi == 1 | con_pens_plst_pi == 1)
	*lab var con_pens_pi "Pension contributor"

	tab con_pens_pi [fw=int(hhweight)]  // 292 th /155 th 
	
	tab pen_publ_ri [fw=int(hhweight)]
	loc totpens = r(sum)
	disp `totpens'

	tab pen_publ_ri [fw=int(hhweight)] if pubsector == 1
	loc pubsector = r(sum)
	disp `pubsector'
	disp (`pubsector'/`totpens')*100

	preserve
	keep id00 d1 con_pens*_in con_pens*_pi pen_* hhweight
	collapse (sum) pen_publ_in con_pens_in con_pens_plst_in con_pens_isrl_in (max) pen_publ_ri con_pens_pi con_pens_plst_pi con_pens_isrl_pi [w=hhweight], by(id00)
	ren (*_pi *_ri *_in) (*_ph *_rh *_hh)

	lab var pen_publ_hh "Pension transfers (retirement)"
	lab var con_pens_hh "Pension contributions"
	lab var con_pens_plst_hh "Pension contributions (Palestine)"
	lab var con_pens_isrl_hh "Pension contributions (Israel)"

	lab var pen_publ_rh "Pension recipient (retirement)"
	lab var con_pens_ph "Pension contributor"
	lab var con_pens_plst_ph "Pension contributor (Palestine)"
	lab var con_pens_isrl_ph "Pension contributor (Israel)"

	save "${temppath}PSE_pensions_hh.dta", replace 
	restore  


* Subtract tax credits 

	*Put together the two parts of Israeli income tax 
	egen dtx_pitx_isrl_in = rowtotal(dtx_pitx_isrl_empl_in dtx_pitx_isrl_pass_in)
	lab var dtx_pitx_isrl_in "Israeli income tax liability"

	// Source: https://h2cat.com/your-taxes-israeli-tax-rates-in-2016/

	* Basic tax credit 
	g crd_basc_isrl_in = 0 
		lab var crd_basc_isrl_in "Basic tax credit"   //Assuming that all men and women file their returns separately 
	replace crd_basc_isrl_in = 2.25*216*12 if female == 0 & dtx_pitx_isrl_pi == 1
	replace crd_basc_isrl_in = 2.75*216*12 if female == 1 & dtx_pitx_isrl_pi == 1
	replace crd_basc_isrl_in = dtx_pitx_isrl_in if crd_basc_isrl_in > dtx_pitx_isrl_in  //99 changes 
	assert !mi(crd_basc_isrl_in) & crd_basc_isrl_in <= dtx_pitx_isrl_in
	replace dtx_pitx_isrl_in = dtx_pitx_isrl_in - crd_basc_isrl_in if formal_isrl == 1
	assert dtx_pitx_isrl_in >= 0 

	* Pension contribution tax credit 
	g crd_pens_isrl_in = 0 
		replace crd_pens_isrl_in = 0.35*con_pens_wrkr_isrl_in if con_pens_isrl_pi == 1 & workertype == 1  //Source: PIT background note, from PIT law a
		lab var crd_pens_isrl_in "Tax credit for pension contributions: employees"
		replace crd_pens_isrl_in = dtx_pitx_isrl_in if crd_pens_isrl_in > dtx_pitx_isrl_in
		assert !mi(crd_pens_isrl_in) & crd_pens_isrl_in <= dtx_pitx_isrl_in
		replace dtx_pitx_isrl_in = dtx_pitx_isrl_in - crd_pens_isrl_in if formal_isrl == 1
		assert dtx_pitx_isrl_in >= 0 

	egen crd_pitx_isrl_in = rowtotal(crd_basc_isrl_in crd_pens_isrl_in)


	*graph twoway scatter dtx_pitx_plst_in pitbracket_plst if dtx_pitx_plst_pi == 1

	qui sum dtx_pitx_plst_in [w=hhweight]
	loc pit_plst_svy = (r(sum))
	if `rerun'{
		putexcel c4 = `pit_plst_svy'
	}
	disp `pit_plst_svy'/1e6   //104 mil 

	qui sum dtx_pitx_plst_pi if dtx_pitx_plst_in  > 0 [w=hhweight]
	disp r(sum)/1e3  //95.9 

	loc pit_plst_admn = 260*1e6

	qui sum dtx_pitx_plst_pi if dtx_pitx_plst_in  > 0 [w=hhweight]
	disp r(sum)/1e3
	
/*************************************
* Remove scaling of PIT entirely (keeping only scaling of deductions)

	loc pit_plst_scalar = (`pit_plst_admn'/$cons_admn)/(`pit_plst_svy'/$cons_svy)
	replace dtx_pitx_plst_in = dtx_pitx_plst_in*`pit_plst_scalar'
	*replace dtx_pitx_isrl_in = dtx_pitx_isrl_in  
		//Note that the lumpiness in the 8th decile is made worse when I remove the scaling from the Israeli portion
*/
	egen dtx_pitx_in = rowtotal(dtx_pitx_plst_in dtx_pitx_isrl_in)


	qui sum dtx_pitx_plst_in [w=hhweight]
	loc pit_plst_svy = (r(sum))
	if `rerun'{
		putexcel e4 = `pit_plst_svy'
	}
	disp `pit_plst_svy'/1e6   //45.2 mil USD // 50.2 mill

	qui sum dtx_pitx_isrl_in [w=hhweight]
	loc pit_isrl_svy = (r(sum))
	if `rerun'{
		putexcel k4 = `pit_isrl_svy'
	}
	disp `pit_isrl_svy'/1e6   //45.2 mil USD // 50.2 mill

	qui sum dtx_pitx_in [w=hhweight]
	disp r(sum)/1e6


	*disp 50.2*`exchange'*1e6

	tab pitbracket_plst  [w=int(hhweight)]
	tab pitbracket_plst [w=int(hhweight)] if workertype == 1 & dtx_pitx_plst_pi == 1 & yt_dedc_in > 0 
	tab pitbracket_plst [w=int(hhweight)] if workertype == 1 & dtx_pitx_plst_pi == 1 & dtx_pitx_plst_pi == 1 & dtx_pitx_plst_in > 0  

	bys id00: egen dtx_pitx_plst_nr = total(dtx_pitx_plst_pi)

	*g foreign = inlist(l6,4,5,6,7)    
	*	lab var foreign "Works in another gov., in Israel, in the settlements or abroad"
	egen dtx_pitx_pi = rowmax(dtx_pitx_plst_pi dtx_pitx_isrl_pi)
	lab var dtx_pitx_pi "PIT Taxpayer"
	lab var dtx_pitx_in "PIT payments"



**********************************************************************
* Calculate
	qui sum dtx_pitx_plst_pi [w=hhweight]
	disp r(sum)/1e3  //109.2 - looks good! 

	qui sum dtx_pitx_plst_in [w=hhweight]
	disp r(sum)/1e6  //214.8

	qui sum con_pens_plst_pi [w=hhweight]
	disp r(sum)/1e3  //146.0

	qui sum con_pens_plst_in [w=hhweight]
	disp r(sum)/1e6  //901.4


	qui sum dtx_pitx_isrl_empl_in [w=hhweight]
	disp r(sum)/1e6  //379.8 

	

	qui sum dtx_pitx_isrl_pi [w=hhweight]
	disp r(sum)/1e3  //46.9 - don't have numbers to compare with.. 

	qui sum dtx_pitx_pi if region == 1 [w=hhweight]
	disp r(sum)/1e3  //78.6 thousand 
	qui sum dtx_pitx_pi if region == 2 [w=hhweight]
	disp r(sum)/1e3  //31.2 thousand 

	tabstat dtx_pitx_pi [w=hhweight], by(dec) stat(sum)

**********************************************************************

save "${temppath}PSE_pit_allvar.dta", replace 

collapse (sum) dtx_pitx_in dtx_pitx_plst_in dtx_pitx_isrl_in (max) dtx_pitx_pi dtx_pitx_plst_pi dtx_pitx_isrl_pi [w=hhweight], by(id00 hhweight dec region dec_wb_gz)
ren (*_in *_pi) (*_hh *_ph)

	lab var dtx_pitx_hh "Income tax (hh)"
	lab var dtx_pitx_plst_hh "Palestinian Income tax (hh)"
	lab var dtx_pitx_isrl_hh "Israeli Income tax (hh)"

	lab var dtx_pitx_ph "Income tax payer (hh)"
	lab var dtx_pitx_plst_ph "Palestinian Income taxpayer (hh)"
	lab var dtx_pitx_isrl_ph "Israeli Income taxpayer (hh)"

save "${temppath}PSE_pit_hh.dta", replace



use "${temppath}PSE_pit_hh.dta", clear



	tabstat dtx_pitx_plst_hh [w=hhweight] if region == 1 | region == 2, by(region) stat(sum)
		tabstat dtx_pitx_plst_hh [w=hhweight], by(region) stat(sum)

use "${temppath}PSE_pensions_hh.dta", clear 



*/
**********************************************************************************************
* END
**********************************************************************************************
