/*********************************************
*****PAKISTAN: Fiscal Incidence Analysis***********
*****World Bank, Poverty and Equity GP*********
***********TTL: Moritz Meyer*****************
*******Consultant: Haydeeliz Carrasco*******
**********************************************/
*Date: Dec 1st, 2021


*OPEN MASTER DATASET
*use "$outputpath\PSE FIA 2017_master data.dta", clear
use "${outputpath}PSE FIA 2017_master data.dta", clear

*SET LOCALS
*ren ambulatory_health_ben amb_health_ben
	local dirtax TOT_dirtax dtx_pitx_plst_hh  dtx_pitx_isrl_hh prop_tax_adj  buil_tax_adj prop_tax_land
	local indtax TOT_indtax TOT_VAT_adj vat_d_adj vat_ind_adj TOT_custom_duty custom_duty_d custom_duty_ind
	local dirtrans TOT_dirtrans govt_cashaid_total govt_kindaid_total
	local indsubs TOT_indsubs subsidy_el  TOT_fuel_sub 
	local health TOT_health_transf  hospitals_health_ben amb_health_ben
	local edu TOT_edu_transf basic_transf second_transf
	local income mktypp netmkty dispy consy finaly
	local concs `dirtax' `dirtrans' `indsubs' `health' `edu' `income' 
	local pline pov_line 

save, replace	

*======RESULT 1: INCIDENCE, BY DECILE===========*
*NOTE: Incidence will be measured at the HH level 
	
**NET CASH POSITION: INCIDENCE BY MARKET INCOME PLUS PENSIONS [PDI Scenario]
*use "$outputpath\PSE FIA 2017_master data.dta", clear //By region
use "${outputpath}PSE FIA 2017_master data.dta", clear
collapse (sum)  TOT_dirtax TOT_dirtrans TOT_indtax TOT_indsubs TOT_health_transf TOT_edu_transf mktypp [fw=int(hhweight)], by(region mktypp_decile)
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet1, modify)

*use "$outputpath\PSE FIA 2017_master data.dta", clear //Total national
use "${outputpath}PSE FIA 2017_master data.dta", clear
collapse (sum)  TOT_dirtax TOT_dirtrans TOT_indtax TOT_indsubs TOT_health_transf TOT_edu_transf mktypp [fw=int(hhweight)], by (mktypp_decile)
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet5, modify)


**INCIDENCE, Detailed, MKTYPP
*use "$outputpath\PSE FIA 2017_master data.dta", clear 
use "${outputpath}PSE FIA 2017_master data.dta", clear
collapse (sum) 	TOT_dirtax dtx_pitx_plst_hh  dtx_pitx_isrl_hh prop_tax_adj  buil_tax_adj prop_tax_land TOT_indtax TOT_VAT_adj vat_d_adj vat_ind_adj TOT_custom_duty custom_duty_d custom_duty_ind TOT_dirtrans govt_cashaid_total govt_kindaid_total TOT_indsubs subsidy_el  TOT_fuel_sub TOT_health_transf  hospitals_health_ben amb_health_ben TOT_edu_transf basic_transf second_transf mktypp [fw=int(hhweight)], by(region mktypp_decile)
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet2, modify)


**INCIDENCE, Detailed, DISPY
*use "$outputpath\PSE FIA 2017_master data.dta", clear
use "${outputpath}PSE FIA 2017_master data.dta", clear
collapse (sum) TOT_dirtax dtx_pitx_plst_hh  dtx_pitx_isrl_hh prop_tax_adj  buil_tax_adj prop_tax_land TOT_indtax TOT_VAT_adj vat_d_adj vat_ind_adj TOT_custom_duty custom_duty_d custom_duty_ind TOT_dirtrans govt_cashaid_total govt_kindaid_total TOT_indsubs subsidy_el  TOT_fuel_sub TOT_health_transf  hospitals_health_ben  amb_health_ben TOT_edu_transf basic_transf second_transf  mktypp  dispy [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet3, modify)

**NET CASH POSITION: INCIDENCE BY MARKET INCOME PLUS PENSIONS [PGT Scenario]
*use "$outputpath\PSE FIA 2017_master data.dta", clear
use "${outputpath}PSE FIA 2017_master data.dta", clear
collapse (sum)  TOT_dirtax_2 TOT_dirtrans_2 TOT_indtax TOT_indsubs TOT_health_transf TOT_edu_transf mkty_2 [fw=int(hhweight)], by(region mkty_2_decile)
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet4, modify)


*================RESULT 2: POVERTY AND GINI===========*
*NATIONAL POVERTY AND INEQUALITY
*use "$outputpath\PSE FIA 2017_master data.dta",  clear
use "${outputpath}PSE FIA 2017_master data.dta", clear
/*sp_groupfunction [aw=popw], gini(`income') theil(`income') poverty(`income') povertyline(pov_line) by(all) 
	
export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet4, modify)*/


********************PDI SCENARIO ****************
*2.1. POVERTY by CEQ Income Concept //CHECK: Poverty using the regional deflator
**West Bank
foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc {
	apoverty `p' [fw=int(popw)] if region==1, varpl(pov_line)
	}

**Gaza
foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc {
	apoverty `p' [fw=int(popw)] if region==2, varpl(pov_line)
	}

**National	
	foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc {
	apoverty `p' [fw=int(popw)] , varpl(pov_line)
	}

*GINI by CEQ Income Concept //CHECK: Inequality using real_pc, should it be only _pc?
**West Bank
foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc finaly_real_pc {
	fastgini `p' [fw=int(popw)] if region==1
	}

**Gaza	
foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc finaly_real_pc {
	fastgini  `p' [fw=int(popw)] if region==2
	}

**National	
	foreach p in mktypp_real_pc netmkty_real_pc dispy_real_pc consy_real_pc finaly_real_pc {
	fastgini  `p' [fw=int(popw)]
	}

	

********************PGT SCENARIO ****************	
**National	
	foreach p in mkty_2_real_pc netmkty_2_real_pc dispy_real_pc consy_real_pc {
	apoverty `p' [fw=int(popw)] , varpl(pov_line)
	}

**National	
	foreach p in mkty_2_real_pc netmkty_2_real_pc dispy_real_pc consy_real_pc finaly_real_pc {
	fastgini  `p' [fw=int(popw)]
	}

		

*================RESULT 3: CONCENTRATION COEFFICIENTS FOR KAKWANIS===========*

*Concentration Coefficients-Detailed
*use "$outputpath\PSE FIA 2017_master data.dta",  clear
use "${outputpath}PSE FIA 2017_master data.dta", clear

	foreach p in TOT_dirtax dtx_pitx_plst_hh  dtx_pitx_isrl_hh prop_tax_adj  buil_tax_adj prop_tax_land TOT_dirtrans govt_cashaid_total govt_kindaid_total  {
				concindexi `p'_real_pc [aw=(popw)] , welfarevar(mktypp_real_pc) clean    
		}
		
		
	foreach p in TOT_indtax TOT_VAT_adj vat_d_adj vat_ind_adj TOT_custom_duty custom_duty_d custom_duty_ind TOT_indsubs subsidy_el  TOT_fuel_sub {
				concindexi `p'_real_pc [aw=(popw)] , welfarevar(dispy_real_pc) clean    
		}

	foreach p in TOT_health_transf  hospitals_health_ben amb_health_ben  TOT_edu_transf basic_transf second_transf {
				concindexi `p'_real_pc [aw=(popw)] , welfarevar(consy_real_pc) clean    
		}

*================RESULT 4: MARGINAL CONTRIBUTIONSs===========================///CHECK
	
*use "$ouputpath\PSE FIA 2017_master data.dta",  clear
use "${outputpath}PSE FIA 2017_master data.dta", clear

	*gen all = 1


	local aux `dirtax' `indtaxes' 
	foreach var of local aux {		
		gen inc_`var'_real_pc = mktypp_real_pc -`var'_real_pc
		local income2 `income2' inc_`var'_real_pc  // Store incomes to marginal contribution calculation		
		}
	local auxII  `dirtrans' `indsubs'  `health' `edu'
	foreach var of local auxII {		
		gen inc_`var'_real_pc = mktypp_real_pc + `var'_real_pc		
		local income2 `income2' inc_`var'_real_pc // Store incomes to marginal contribution calculation
	}

*sp_groupfunction [aw=popw], gini(`income_real_pc' `income2') theil(`income_real_pc' `income2') poverty(`income_real_pc' `income2') povertyline(`pline')  by(all) // HC: CHECK WHY IS NOT WORKING??
	

export excel using "$results\PSE FIA_Main results.xls", firstrow(var) sheet(Sheet5, modify)	 //HC: Check why spgroupfunction is not working?
	

*===========RESULT 5: INTERNATIONAL POVERTY================================*
*use "$outputpath\PSE FIA 2017_master data.dta",  clear
use "${outputpath}PSE FIA 2017_master data.dta", clear

*INTERNATIONAL POVERTY
gen pov_55=2.437905*5.5*(365/12) //$5.5 PPP 2011 poverty line


foreach p in mktypp_pc dispy_pc consy_pc {
		apoverty `p' [fw=int(popweight)], varpl(pov_55)
}
