/*********************************************
*****PAKISTAN: Fiscal Incidence Analysis***********
*****World Bank, Poverty and Equity GP*********
***********TTL: Arden Finn and Alia Jane*****************
*******Consultant: Haydeeliz Carrasco*******
**********************************************/
*Date: May 5th 2022

/*DOFILE: GENERATE CEQ INCOME CONCEPTS */


****MERGE ALL DATASETS WITH SIMULATED FISCAL INTERVENTIONS ******
use "${temppath}PSE_pit_hh.dta", clear

	merge 1:1 id00 using "${temppath}PSE_pensions_hh.dta" 
		drop _m
	ren id00 hhid
	merge 1:1 hhid using "${temppath}PSE_Prop tax results.dta" 
		drop _m
	merge 1:1 hhid using "${temppath}PSE_SP results.dta"
		drop _m	
	merge 1:1 hhid using "${temppath}PSE_VAT results_HH.dta"
		drop _m	
	merge 1:1 hhid using "${temppath}PSE_Custom Duties results_HH.dta"
		drop _m
	merge 1:1 hhid using "${temppath}energy_PSE final.dta"
		drop _m	
	merge 1:1 hhid using  "${temppath}PSE_Fuel Subsidies_HH.dta"
		drop _m	
		merge 1:1 hhid using "${temppath}PSE_Health transfers_HH.dta"
		drop _m
	merge 1:1 hhid using "${temppath}PSE_Edu transfers_HH.dta"
		drop _m	
	merge 1:1 hhid using "${temppath}PSE_Fuel Excises_HH.dta" //HC: New dataset added
		drop _m
	merge 1:1 hhid using  "${datapath}PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta" 
		drop if _m!=3
		drop _m
		
	
	*Generate aggregates of fiscal interventions
	mvencode _all, mv(0) overr
	
	*Exclude East Jerusalem from transfers
	foreach p in TOT_fuel_sub fuel_sub_d fuel_sub_ind subsidy_el TOT_health_transf  hospitals_health_ben ambulatory_health_ben TOT_edu_transf  basic_transf second_transf  { 
		replace `p'=0 if id01==40|id01==41
	}	

*===============================================================================	
*	Create CEQ INCOME AGGREGATES 
*===============================================================================


******************PDI SCENARIO**************
gen TOT_dirtax=dtx_pitx_hh + prop_tax_adj  
gen TOT_dirtrans=govt_cashaid_total +govt_kindaid_total
gen TOT_indtax=TOT_VAT_adj +TOT_custom_duty+TOT_fuel_exc
gen TOT_indsubs=subsidy_el +TOT_fuel_sub 
	
	gen dispy=gall_n_hh
	
	gen netmkty=dispy-TOT_dirtrans
		replace netmkty=0 if netmkty<0
		
	gen mktypp=netmkty+TOT_dirtax 
		replace mktypp=0 if mktypp<0
		
	gen consy=dispy-TOT_indtax+TOT_indsubs
		replace consy=0 if consy<0
		
	gen finaly=consy+TOT_health_transf+TOT_edu_transf
	

******************PGT SCENARIO**************
gen TOT_dirtax_2=dtx_pitx_hh + prop_tax_adj + con_pens_hh
gen TOT_dirtrans_2=govt_cashaid_total +govt_kindaid_total+pen_publ_hh 
	
	gen netmkty_2=dispy-TOT_dirtrans_2
		replace netmkty_2=0 if netmkty_2<0
		
	gen mkty_2=netmkty+TOT_dirtax_2 
		replace mkty_2=0 if mkty_2<0
	
	*Convert variables for poverty and inequality calculations
	ren ambulatory_health_ben amb_health_ben
	local pensions pen_publ_hh
	local cont con_pens_hh con_pens_isrl_hh con_pens_plst_hh
	local dirtax TOT_dirtax dtx_pitx_hh dtx_pitx_plst_hh  dtx_pitx_isrl_hh prop_tax_adj  buil_tax_adj prop_tax_land
	local indtax TOT_indtax TOT_VAT_adj vat_d_adj vat_ind_adj TOT_custom_duty custom_duty_d custom_duty_ind TOT_fuel_exc fuel_exc_d fuel_exc_ind
	local dirtrans TOT_dirtrans govt_cashaid_total govt_kindaid_total
	local indsubs TOT_indsubs subsidy_el  TOT_fuel_sub fuel_sub_d fuel_sub_ind
	local health TOT_health_transf  hospitals_health_ben amb_health_ben
	local edu TOT_edu_transf basic_transf second_transf
	local income mktypp netmkty dispy consy finaly mkty_2 netmkty_2
	local concs `pensions' `cont' `dirtax' `dirtrans' `indsubs' `health' `edu' `income' `indtax'
	
	**Per adult equivalent (for inequality)
	
	foreach i of local concs {
		gen `i'_pc=`i'/hhsize
	}

	**Real, per adult equivalent (for poverty)
	foreach i of local concs {
	gen `i'_real_pc=`i'_pc/rdef
	}
	
*===============================================================================	
*	GENERATE ADDITIONAL VARIABLES
*===============================================================================
	 
*National Poverty Line
	gen pov_line= pline_g

*International Poverty Line (PPP 2011)
	*gen pov_19= 12469*(1+$inflation)    //Annual Poverty Line, at GMD (USD 1.9 a day, PPP)
	*gen pov_32= 21000*(1+$inflation)  //Annual Poverty Line,-closest to national poverty line of GMD 18K
	*gen pov_55=36094*(1+$inflation) //Annual Poverty Line
	*gen pov_217= 142408*(1+$inflation)  //Annual Poverty Line, at GMD (USD 2.17 a day, PPP)

*GENERATE DECILES

replace region=1 if region==3

*Deciles by Market Income plus Pensions, per adult equivalent

*PDI Scenario
quantiles mktypp_real_pc [w=popw] if region ==1, nq(10) gencatvar(mktypp_dec1)
quantiles mktypp_real_pc [w=popw] if region ==2, nq(10) gencatvar(mktypp_dec2)
gen mktypp_decile=mktypp_dec1 if region==1 
replace mktypp_decile=mktypp_dec2 if region==2


*PGT Scenario
quantiles mkty_2_real_pc [w=popw] if region ==1, nq(10) gencatvar(mkty2_dec1)
quantiles mkty_2_real_pc [w=popw] if region ==2, nq(10) gencatvar(mkty2_dec2)
gen mkty_2_decile=mkty2_dec1 if region==1 
replace mkty_2_decile=mkty2_dec2 if region==2


*Deciles by Disposable Income (Alternative)
drop decile
quantiles dispy_real_pc [w=popw] if region ==1, nq(10) gencatvar(dispy_dec1)
quantiles dispy_real_pc [w=popw] if region ==2, nq(10) gencatvar(dispy_dec2)
gen decile=dispy_dec1 if region==1 
replace decile=dispy_dec2 if region==2


mvencode _all, mv(0) overr

*save "$outputpath\PSE FIA 2017_master data.dta", replace	//why global path is not found?
save "${outputpath}PSE FIA 2017_master data.dta", replace
label data "PALESTINE Fiscal Incidence Analysis 2017, master data for analysis"
	
	
